#!/usr/bin/env python

# ../openexr-images/MultiResolution:
# Bonita.exr              MirrorPattern.exr       StageEnvCube.exr
# ColorCodedLevels.exr    OrientationCube.exr     StageEnvLatLong.exr
# Kapaa.exr               OrientationLatLong.exr  WavyLinesCube.exr
# KernerEnvCube.exr       PeriodicPattern.exr     WavyLinesLatLong.exr
# KernerEnvLatLong.exr    README                  WavyLinesSphere.exr
imagedir = OIIO_TESTSUITE_IMAGEDIR + "/MultiResolution"
files = [ "Bonita.exr", "ColorCodedLevels.exr",
          # FIXME -- we don't know how to deal with RIP-maps -- Kapaa, 
          "KernerEnvCube.exr", "KernerEnvLatLong.exr", "MirrorPattern.exr",
          "OrientationCube.exr", "OrientationLatLong.exr",
          "PeriodicPattern.exr", "StageEnvCube.exr", "StageEnvLatLong.exr",
          "WavyLinesCube.exr", "WavyLinesLatLong.exr", "WavyLinesSphere.exr" ]
for f in files:
    command += rw_command (imagedir, f)


# ../openexr-images/MultiView
# Adjuster.exr  Balls.exr  Fog.exr  Impact.exr  LosPadres.exr
imagedir = OIIO_TESTSUITE_IMAGEDIR + "/MultiView"
files = [ "Adjuster.exr", "Balls.exr", "Fog.exr", "Impact.exr", "LosPadres.exr" ]
for f in files:
    command += rw_command (imagedir, f)



#!/usr/bin/env python

imagedir = OIIO_TESTSUITE_IMAGEDIR
refdir = imagedir + "/ref/"
refdirlist = [ "ref/", refdir ]
outputs = [ ]


# Define a handy function that runs an oiiotool command, and
# also diffs the result against a reference image.
def oiiotool_and_test (inputfile, ops, outputfile, precommand="") :
    cmd = oiiotool (precommand + " " + imagedir + "/" + inputfile +
                    " " + ops + " -o " + outputfile)
    outputs.append (outputfile)
    return cmd



# Test fit with pad on DPX
command += oiiotool_and_test ("testFullFrame_2kfa_lg10.0006.dpx",
                              "--fit:pad=1 512x512", "fit_lg10.dpx")

# Conversion of linear half exr to vd16 uint16 TIFF
# at very high resolution used for marketing stills.
command += oiiotool_and_test ("mkt019_comp_wayn_fullres_s3d_lf_v51_misc_lnh.1001.exr",
                              "--croptofull --colorconvert:unpremult=1 lnh vd16 --ch R,G,B,A -d uint16",
                              "mkt019_comp_wayn_fullres_s3d_lf_v51_alpha_misc_vd16.1001.tif",
                              precommand = "--colorconfig " + imagedir + "/ht2.ocio/config.ocio")

# Test fit/cut on JPEG
command += oiiotool_and_test ("ffr0830_avid_ref_v3_hd_ref8.1024.jpg",
                              "--fit 2154x0 --cut 2154x1137+0+38 --cut 2154x1136",
                              "ffr0830_avid_ref_match_v3_2kdcip_ref8.1024.jpg")

# Test fit + color conversion + DPX->JPEG
# N.B. 
command += oiiotool_and_test ("ep0400_bg1_v101_3kalxog_alogc16.1001.dpx",
                              "--fit 1028x662 --colorconvert alogc16 vd8",
                              "ep0400-v2_bg1_v101_1kalxog_vd8.1001.jpg",
                              precommand = "--colorconfig " + imagedir + "/pxl.ocio/config.ocio")

# Test ociofiletransform
command += oiiotool_and_test ("os0225_110_lightingfix_v002.0101.dpx",
                              "--colorconvert lm10 lnf --ociofiletransform srgb_look.csp --colorconvert lnf vd8 -d uint8",
                              "os0225_110_lightingfix_v002.0101.png",
                              precommand = "--colorconfig " + imagedir + "/os4.ocio/config.ocio")

# Test read of iff
command += oiiotool_and_test ("iff/iff_vd8.1001.iff",
                              "",
                              "./iff_vd8.1001.iff")
command += info_command ("iff_vd8.1001.iff")


# Regression test on dealing with DPX with overscan
# REMOVED -- DPX spec doesn't support overscan!
#command += oiiotool_and_test ("dpxoverscan_hg0700_fg1_v2_2kdciufa_lg16.1014.dpx",
#                              "--iscolorspace lg16 --crop -2,0,2401,911 --fullpixels",
#                              "dpxoverscan_lg16.dpx")

outputs += [ "out.txt" ]



#!/usr/bin/env python

from __future__ import print_function
from __future__ import absolute_import
import os
import OpenImageIO as oiio


try:
    config = oiio.ColorConfig()
    print ("getNumColorSpaces =", config.getNumColorSpaces())
    print ("getColorSpaceNames =", config.getColorSpaceNames())

    print ("getNumLooks =", config.getNumLooks())
    print ("getLookNames =", config.getLookNames())

    print ("getNumDisplays =", config.getNumDisplays())
    print ("getDisplayNames =", config.getDisplayNames())
    print ("getDefaultDisplayName =", config.getDefaultDisplayName())

    print ("getNumViews =", config.getNumViews())
    print ("getViewNames =", config.getViewNames())
    print ("getDefaultViewName =", config.getDefaultViewName())

    print ("getNumRoles =", config.getNumRoles())
    print ("getRoles =", config.getRoles())

    print ("")

    print ("Done.")
except Exception as detail:
    print ("Unknown exception:", detail)




#!/usr/bin/env python

####################################################################
# This test exercises oiiotool functionality that is mostly about
# copying pixels from one image to another.
####################################################################


# Some tests to verify that we are transferring data formats properly.
#
command += oiiotool ("-pattern checker 128x128 3 -d uint8 -tile 16 16 -o uint8.tif " +
                     "-echo \"explicit -d uint save result: \" -metamatch \"width|tile\" -i:info=2 uint8.tif -echo \"\"")
# Un-modified copy should preserve data type and tiling
command += oiiotool ("uint8.tif -o tmp.tif " +
                     "-echo \"unmodified copy result: \" -metamatch \"width|tile\" -i:info=2 tmp.tif -echo \"\"")
# Copy with explicit data request should change data type
command += oiiotool ("uint8.tif -d uint16 -o copy_uint16.tif " +
                     "-echo \"copy with explicit -d uint16 result: \" -metamatch \"width|tile\" -i:info=2 copy_uint16.tif -echo \"\"")
# Subimage concatenation should preserve data type
command += oiiotool ("uint8.tif copy_uint16.tif -siappend -o tmp.tif " +
                     "-echo \"siappend result: \" -metamatch \"width|tile\" -i:info=2 tmp.tif -echo \"\"")
# Combining two images preserves the format of the first read input, if
# there are not any other hints:
command += oiiotool ("-pattern checker 128x128 3 uint8.tif -add -o tmp.tif " +
                     "-echo \"combining images result: \" -metamatch \"width|tile\" -i:info=2 tmp.tif -echo \"\"")

# test --crop
command += oiiotool (OIIO_TESTSUITE_IMAGEDIR + "/grid.tif --crop 100x400+50+200 -o crop.tif")

# test --cut
command += oiiotool (OIIO_TESTSUITE_IMAGEDIR + "/grid.tif --cut 100x400+50+200 -o cut.tif")

# test --paste
command += oiiotool (OIIO_TESTSUITE_IMAGEDIR + "/grid.tif "
            + "--pattern checker 256x256 3 --paste +150+75 -o pasted.tif")

# test --pastemeta
command += oiiotool ("--pattern:type=half constant:color=0,1,0 64x64 3 -o green.exr")
command += oiiotool ("--pattern:type=half constant:color=1,0,0 64x64 3 -attrib hair brown -attrib eyes 2 -attrib weight 20.5 -o redmeta.exr")
command += oiiotool ("redmeta.exr green.exr --pastemeta -o greenmeta.exr")
command += info_command ("green.exr", safematch=True)
command += info_command ("greenmeta.exr", safematch=True)

# test mosaic
# Purposely test with fewer images than the mosaic array size
command += oiiotool ("--pattern constant:color=1,0,0 50x50 3 "
            + "--pattern constant:color=0,1,0 50x50 3 "
            + "--pattern constant:color=0,0,1 50x50 3 "
            + "--mosaic:pad=10 2x2 -d uint8 -o mosaic.tif")


# test --metamerge, using chappend as an example
command += oiiotool ("--create 64x64 3 -chnames R,G,B -attrib a 3.0 -o aimg.exr")
command += oiiotool ("--create 64x64 3 -chnames A,Z -attrib b 1.0 -o bimg.exr")
command += oiiotool ("aimg.exr bimg.exr --chappend -o nometamerge.exr")
command += oiiotool ("--metamerge aimg.exr bimg.exr --chappend -o metamerge.exr")
command += info_command ("nometamerge.exr", safematch=True)
command += info_command ("metamerge.exr", safematch=True)

# test --chappend of multiple images
command += oiiotool ("--pattern constant:color=0.5 64x64 1 --text R --chnames R " +
                     "--pattern constant:color=0.25,0.75 64x64 2 --text G,B --chnames G,B " +
                     "--pattern constant:color=1.0 64x64 1 --text A --chnames A " +
                     "--chappend:n=3 -d half -o chappend-3images.exr")



# Outputs to check against references
outputs = [
            "crop.tif", "cut.tif", "pasted.tif", "mosaic.tif",
            "greenmeta.exr",
            "chappend-3images.exr",
            "out.txt"
          ]

#print "Running this command:\n" + command + "\n"



#!/usr/bin/env python
#import OpenImageIO as oiio
from __future__ import division
from __future__ import absolute_import
import shutil
import os

## This testsuite entry tests oiiotool features related to image
## transformations (moving pixels around and resampling).


# helper function
def make_test_pattern1 (filename, xres=288, yres=216) :
    buf = oiio.ImageBuf (oiio.ImageSpec (xres, yres, 3, oiio.HALF))
    for y in range(yres) :
        for x in range(xres) :
            b = 0.25 + 0.5 * float (((x//16) & 1) ^ ((y//16) & 1))
            if x == 1 or y == 1 or x == xres-2 or y == yres-2 :
                b = 0.0
            if (((x >= 10 and x <= 20) or (x >= xres-20 and x <= xres-10)) and
                ((y >= 10 and y <= 20) or (y >= yres-20 and y <= yres-10))) :
                b = 0.0
            if ((x == 15 or x == xres-15) and (y == 15 or y == yres-15)) :
                b = 1.0
            buf.setpixel (x, y, (float(x)/1000.0, float(y)/1000.0, b))
    buf.write (filename)


# Create some test images we need
# No need to do this every time, we stashed it in src
#make_test_pattern1 ("src/target1.exr", 288, 216)

oiiotoolsrcdir = os.path.join(OIIO_TESTSUITE_ROOT, "oiiotool", "src")
shutil.copy (oiiotoolsrcdir + "/tahoe-tiny.tif", "./tahoe-tiny.tif")
shutil.copy (oiiotoolsrcdir + "/tahoe-small.tif", "./tahoe-small.tif")
shutil.copy (oiiotoolsrcdir + "/image.tif", "./image.tif")


# test resample
command += oiiotool (OIIO_TESTSUITE_IMAGEDIR + "/grid.tif --resample 128x128 -o resample.tif")

# test resize
command += oiiotool (OIIO_TESTSUITE_IMAGEDIR + "/grid.tif --resize 256x256 -o resize.tif")
command += oiiotool (OIIO_TESTSUITE_IMAGEDIR + "/grid.tif --resize 25% -o resize2.tif")

# test extreme resize
command += oiiotool (OIIO_TESTSUITE_IMAGEDIR + "/grid.tif --resize 64x64 -o resize64.tif")
command += oiiotool ("resize64.tif --resize 512x512 -o resize512.tif")

# test resize with nonzero origin. Save to exr to make extra sure we have
# the display and data windows correct.
command += oiiotool ("--pattern fill:topleft=1,0,0:topright=0,1,0:bottomleft=0,0,1:bottomright=0,1,1 64x64 3 " +
                     "--origin +100+100 --fullsize 256x256+0+0 " +
                     "--resize 128x128 -d half -o resized-offset.exr")
# test fit
command += oiiotool (OIIO_TESTSUITE_IMAGEDIR + "/grid.tif --fit 360x240 -d uint8 -o fit.tif")
command += oiiotool (OIIO_TESTSUITE_IMAGEDIR + "/grid.tif --fit 240x360 -d uint8 -o fit2.tif")
# regression test: --fit without needing resize used to be problematic
command += oiiotool ("tahoe-tiny.tif --fit 128x128 -d uint8 -o fit3.tif")
# test --fit:exact=1 when we can't get a precise whole-pixel fit of aspect
command += oiiotool ("src/target1.exr --fit:exact=1:filter=blackman-harris 216x162 -o fit4.exr")

# test --pixelaspect
command += oiiotool ("tahoe-small.tif -resize 256x192 --pixelaspect 2.0 -d uint8 -o pixelaspect.tif")

# test rotate
command += oiiotool ("resize.tif --rotate 45 -o rotated.tif")
command += oiiotool ("resize.tif --rotate:center=50,50 45 -o rotated-offcenter.tif")
command += oiiotool ("resize.tif --rotate 45 --rotate 90 --rotate 90 --rotate 90 --rotate 45 -o rotated360.tif")

# test warp
command += oiiotool ("resize.tif --warp 0.7071068,0.7071068,0,-0.7071068,0.7071068,0,128,-53.01933,1 -o warped.tif")

# test flip
command += oiiotool ("image.tif --flip -o flip.tif")
command += oiiotool ("image.tif --crop 180x140+30+30 --flip -o flip-crop.tif")

# test flop
command += oiiotool ("image.tif --flop -o flop.tif")
command += oiiotool ("image.tif --crop 180x140+30+30 --flop -o flop-crop.tif")

# test rotate90
command += oiiotool ("image.tif --rotate90 -o rotate90.tif")
command += oiiotool ("image.tif --crop 180x140+30+30 --rotate90 -o rotate90-crop.tif")

# test rotate270
command += oiiotool ("image.tif --rotate270 -o rotate270.tif")
command += oiiotool ("image.tif --crop 180x140+30+30 --rotate270 -o rotate270-crop.tif")

# test rotate180
command += oiiotool ("image.tif --rotate180 -o flipflop.tif")
command += oiiotool ("image.tif --crop 160x120+30+30 --rotate180 -o flipflop-crop.tif")

# Tricky: make image, rotate, set Orientation, and then re-orient.
# Make it half size so it can't accidentally match to another test image
# for the rotation tests.
command += oiiotool ("image.tif --resample 160x120 --rotate90  --orientccw --reorient -o reorient1.tif")
command += oiiotool ("image.tif --resample 160x120 --rotate180 --orient180 --reorient -o reorient2.tif")
command += oiiotool ("image.tif --resample 160x120 --rotate270 --orientcw  --reorient -o reorient3.tif")

# test transpose
command += oiiotool ("image.tif --transpose -o transpose.tif")
command += oiiotool ("image.tif --crop 160x120+30+30 --transpose -o transpose-crop.tif")

# test cshift
command += oiiotool ("image.tif --cshift +100+50 -o cshift.tif")


# To add more tests, just append more lines like the above and also add
# the new 'feature.tif' (or whatever you call it) to the outputs list,
# below.


# Outputs to check against references
outputs = [
            "resample.tif", "resize.tif", "resize2.tif",
            "resize64.tif", "resize512.tif",
            "resized-offset.exr",
            "fit.tif", "fit2.tif", "fit3.tif", "fit4.exr",
            "pixelaspect.tif",
            "warped.tif",
            "rotated.tif", "rotated-offcenter.tif", "rotated360.tif",
            "flip.tif", "flip-crop.tif",
            "flop.tif", "flop-crop.tif",
            "flipflop.tif", "flipflop-crop.tif",
            "rotate90.tif", "rotate90-crop.tif",
            "rotate270.tif", "rotate270-crop.tif",
            "reorient1.tif", "reorient2.tif", "reorient3.tif",
            "transpose.tif", "transpose-crop.tif",
            "cshift.tif",
            "out.txt" ]

#print "Running this command:\n" + command + "\n"



#!/usr/bin/env python

# Miscellaneous TIFF-related tests

outputs = [ ]

# Regression test -- we once had a bug where 'separate' planarconfig
# tiled float files would have data corrupted by a buffer overwrite.
command += oiiotool("--pattern checker 128x128 4 --tile 64 64 --planarconfig separate -d float -o check1.tif")
outputs += [ "check1.tif" ]

# Test bug we had until OIIO 2.3 when reading planarconfig=separate files
# (fixed by #2757) that was not detected by the uncompressed file. So copy
# to force compression in order to properly test:
command += rw_command ("src", "separate.tif")



#!/usr/bin/env python

imagedir = OIIO_TESTSUITE_IMAGEDIR + "/targa"

files = [ "CBW8.TGA", "CCM8.TGA", "CTC16.TGA", "CTC24.TGA", "CTC32.TGA",
          "UBW8.TGA", "UCM8.TGA", "UTC16.TGA", "UTC24.TGA", "UTC32.TGA",
          "round_grill.tga" ]
for f in files:
    command += rw_command (imagedir, f)



#!/usr/bin/env python

# Copyright Contributors to the OpenImageIO project.
# SPDX-License-Identifier: BSD-3-Clause
# https://github.com/OpenImageIO/oiio


command += run_app("cmake " + test_source_dir + " -DCMAKE_BUILD_TYPE=Release >> build.txt 2>&1", silent=True)
command += run_app("cmake --build . --config Release >> build.txt 2>&1", silent=True)
if platform.system() == 'Windows' :
    command += run_app("Release\\consumer")
else :
    command += run_app("./consumer")



#!/usr/bin/env python


command += oiiotool ("-pattern constant:color=.5,.1,.1 256x256 3 -text:size=50:x=75:y=140 1001 -d uint8 -otex file.1001.tx")
command += oiiotool ("-pattern constant:color=.1,.5,.1 256x256 3 -text:size=50:x=75:y=140 1002 -d uint8 -otex file.1002.tx")
command += oiiotool ("-pattern constant:color=.1,.1,.5 256x256 3 -text:size=50:x=75:y=140 1011 -d uint8 -otex file.1011.tx")
command += oiiotool ("-pattern constant:color=.1,.5,.5 256x256 3 -text:size=50:x=75:y=140 1012 -d uint8 -otex file.1012.tx")

command += testtex_command ("\"file.<UDIM>.tx\"",
                            "-nowarp -scalest 2 2 --iters 100 -res 128 128 -d uint8 -o out.tif")
#command += diff_command ("out.tif", "ref/out.tif", "--fail 0.0005 --warn 0.0005")

outputs = [ "out.tif" ]



#!/usr/bin/env python 

# test --create
command += oiiotool ("--create 320x240 3 -d uint8 -o black.tif")
command += oiiotool ("--stats black.tif")

# test --pattern constant
command += oiiotool ("--pattern constant:color=.1,.2,.3,1 320x240 4 -o constant.tif")
command += oiiotool ("--stats constant.tif")

# test --pattern noise
command += oiiotool ("--pattern noise:type=uniform:min=0.25:max=0.75 64x64 3 -d uint8 -o noise-uniform3.tif")
command += oiiotool ("--pattern noise:type=gaussian:mean=0.5:stddev=0.1 64x64 3 -d uint8 -o noise-gauss.tif")
command += oiiotool ("--pattern noise:type=salt:portion=0.01:value=1 64x64 3 -d uint8 -o noise-salt.tif")

# test --pattern fill
command += oiiotool ("--pattern fill:color=0,0,0.5 64x64 3 -d uint8 -o pattern-const.tif")
command += oiiotool ("--pattern fill:top=0.1,0.1,0.1:bottom=0,0,0.5 64x64 3 -d uint8 -o pattern-gradientv.tif")
command += oiiotool ("--pattern fill:left=0.1,0.1,0.1:right=0,0.5,0 64x64 3 -d uint8 -o pattern-gradienth.tif")
command += oiiotool ("--pattern fill:topleft=0.1,0.1,0.1:topright=0,0.5,0:bottomleft=0.5,0,0:bottomright=0,0,0.5 64x64 3 -d uint8 -o pattern-gradient4.tif")

# test --fill
command += oiiotool ("--create 256x256 3 --fill:color=1,.5,.5 256x256 --fill:color=0,1,0 80x80+100+100 -d uint8 -o filled.tif")
command += oiiotool ("--create 64x64 3 --fill:top=0.1,0.1,0.1:bottom=0,0,0.5 64x64 -d uint8 -o fillv.tif")
command += oiiotool ("--create 64x64 3 --fill:left=0.1,0.1,0.1:right=0,0.5,0 64x64 -d uint8 -o fillh.tif")
command += oiiotool ("--create 64x64 3 --fill:topleft=0.1,0.1,0.1:topright=0,0.5,0:bottomleft=0.5,0,0:bottomright=0,0,0.5 64x64 -d uint8 -o fill4.tif")

# test --line
command += oiiotool ("--pattern checker:color1=.1,.1,.1:color2=0,0,0 256x256 3 " +
                     "-line:color=0.25,0,0,0.25 10,60,250,20 " +
                     "-line:color=0.5,0,0,0.5   10,62,250,100 " +
                     "-line:color=1,0,0,1       10,64,250,400 " +
                     "-line:color=0,1,0,1       250,100,10,184 " +
                     "-line:color=0,0.5,0,0.5   250,200,10,182 " +
                     "-line:color=0,0.25,0,0.25 100,400,10,180 " +
                     "-line:color=.5,.5,0,0.5  100,100,120,100,120,100,120,120,120,120,100,120,100,120,100,100 " +
                     "-box:color=0,0.5,0.5,0.5  150,100,240,180 " +
                     "-d uint8 -o lines.tif")

# test --box
command += oiiotool ("--pattern checker:color1=.1,.1,.1:color2=0,0,0 256x256 3 " +
                     "--box:color=0,1,1,1 150,100,240,180 " +
                     "--box:color=0.5,0.5,0,0.5:fill=1 100,50,180,140  " +
                     "-d uint8 -o box.tif")



# To add more tests, just append more lines like the above and also add
# the new 'feature.tif' (or whatever you call it) to the outputs list,
# below.


# Outputs to check against references
outputs = [ "pattern-const.tif", "pattern-gradienth.tif",
            "pattern-gradientv.tif", "pattern-gradient4.tif",
            "noise-uniform3.tif", "noise-gauss.tif", "noise-salt.tif",
            "filled.tif", "fillh.tif", "fillv.tif", "fill4.tif",
            "lines.tif", "box.tif",
            "out.txt" ]

#print "Running this command:\n" + command + "\n"



#!/usr/bin/env python

# Test oiiotool's ability to add and delete attributes


# Test --eraseattrib ability to erase one specific attribute
# The result should not have "Make"
command += oiiotool (OIIO_TESTSUITE_IMAGEDIR+"/tahoe-gps.jpg --eraseattrib Make -o nomake.jpg")
command += info_command ("nomake.jpg", safematch=True)

# Test --eraseattrib ability to match patterns
# The result should have no GPS tags
command += oiiotool (OIIO_TESTSUITE_IMAGEDIR+"/tahoe-gps.jpg --eraseattrib \"GPS:.*\" -o nogps.jpg")
command += info_command ("nogps.jpg", safematch=True)

# Test --eraseattrib ability to strip all attribs
# The result should be very minimal
command += oiiotool (OIIO_TESTSUITE_IMAGEDIR+"/tahoe-gps.jpg --eraseattrib \".*\" -o noattribs.jpg")
command += info_command ("noattribs.jpg", safematch=True)

# Test adding and erasing attribs to multiple subimages
command += oiiotool ("--create 64x64 3 -dup --siappend " +
                     "--attrib:allsubimages=1 foo bar -d half -o attrib2.exr")
command += info_command ("attrib2.exr", safematch=True)
command += oiiotool ("attrib2.exr " +
                     "--eraseattrib:allsubimages=1 foo -d half -o attrib0.exr")
command += info_command ("attrib0.exr", safematch=True)



#!/usr/bin/env python

files = [ "1.webp", "2.webp", "3.webp", "4.webp" ]
for f in files:
    command += info_command (OIIO_TESTSUITE_IMAGEDIR + "/" + f)
    # We should also test read/write, but it's really hard to because it's
    # a lossy format and is not stable under the round trip
    # command += rw_command (OIIO_TESTSUITE_IMAGEDIR, f,
    #                        extraargs='-attrib compression lossless')



#!/usr/bin/env python

outputs = []

for f in [ "sphere.vdb", "sphereCd.vdb" ]:
    vdbfile = os.path.join('src', f)
    exrfile = os.path.splitext(f)[0] + '.exr'
    command += "%s --nowarp --offset -1 -1 -1 --scalest 2 2 %s -o %s\n" % (oiio_app("testtex"), vdbfile, exrfile)
    outputs.append(exrfile)



#!/usr/bin/env python 

# OLD CODE: (result ramp.exr is now checked into src)
# import OpenImageIO as oiio
# 
# # Make a ramp image, left half is increating r at rate dr/ds = 0.5, dr/dt = 0,
# # right half is increasing r at rate dr/ds = 0, dr/dt = 0.5
# b = oiio.ImageBuf (oiio.ImageSpec(128,128,3,oiio.FLOAT))
# for y in range(128) :
#     for x in range(128) :
#         if x < 64 :
#             b.setpixel (x, y, 0, (float(0.5*x)/128.0, 0.0, 0.1))
#         else:
#             b.setpixel (x, y, 0, (float(0.5*y)/128.0, 0.0, 0.1))
# b.write ("ramp.exr")

command = testtex_command ("-res 128 128 -nowarp -wrap clamp -derivs src/ramp.exr")
outputs = [ "out.exr", "out.exr-ds.exr", "out.exr-dt.exr" ]



#!/usr/bin/env python

from __future__ import print_function
from __future__ import absolute_import
import numpy
import OpenImageIO as oiio


def print_param_value(p) :
    if type(p.value) == float :
        print ("  item {} {} {:.6}".format(p.name, p.type, p.value))
    else :
        print ("  item {} {} {}".format(p.name, p.type, p.value))

def print_param_list(pl) :
    for p in pl :
        print_param_value(p)



######################################################################
# main test starts here

try:
    print ("Testing individual ParamValue:")
    # Construct from scalars
    pv = oiio.ParamValue("a", 42)
    print_param_value(pv)
    pv = oiio.ParamValue("b", 3.5)
    print_param_value(pv)
    pv = oiio.ParamValue("c", "xyzpdq")
    print_param_value(pv)
    # Construct from tuple
    pv = oiio.ParamValue("d", "float[4]", (3.5, 4.5, 5.5, 6.5))
    print_param_value(pv)
    # Construct from tuple with nvalues/interp
    pv = oiio.ParamValue("e", "float", 4, oiio.Interp.LINEAR, (1, 3, 5, 7))
    print_param_value(pv)
    # Construct from a list
    pv = oiio.ParamValue("f", "point", [3.5, 4.5, 5.5, 6.5])
    print_param_value(pv)
    # Construct from a numpy array
    pv = oiio.ParamValue("g", "color",
                         numpy.array([0.25, 0.5, 0.75], dtype='f'))
    print_param_value(pv)

    print ("")

    print ("Testing ParamValueList:")
    pl = oiio.ParamValueList()
    pl.attribute ("i", 1)
    pl.attribute ("s", "Bob")
    pl.attribute ("e", 2.718281828459045)
    pl.attribute ("P", "point", (2.0, 42.0, 1.0))
    pl.attribute ("pressure", "float", 4, [98.0, 98.5, 99.0, 99.5])
    pl["j"] = 42
    pl["foo"] = "bar"
    pl["pi"] = 3.141592653589793

    print ("pl length is", len(pl))
    print_param_list (pl)

    print ("pl.contains('e') =", pl.contains('e'))
    print ("pl.contains('f') =", pl.contains('f'))
    print ("pl[1] =", pl[1].name, pl[1].type, pl[1].value)
    print ("pl['e'] = {:.6}".format(pl['e']))
    print ("pl['pi'] = {:.6}".format(pl['pi']))
    print ("pl['foo'] =", pl['foo'])

    pl.remove('e')
    print ("after removing 'e', len=", len(pl), "pl.contains('e')=", pl.contains('e'))

    pl2 = oiio.ParamValueList()
    pl2.attribute ("a", "aval")
    pl2.attribute ("m", 1)
    print ("pl2 =")
    print_param_list(pl2)
    pl.merge(pl2)
    print ("After merge, pl =")
    print_param_list(pl)

    pl.sort()
    print ("after sorting:")
    print_param_list(pl)

    print ("Done.")
except Exception as detail:
    print ("Unknown exception:", detail)




#!/usr/bin/env python

# Test "missingcolor" attribute by reading a tiled exr that deliberately has
# missing tiles. Make sure that we do the right thing in the presence of
# missingcolor attribute.

# change redirection to send stderr to a separate file
redirect = " >> out.txt 2>> out.err.txt "
failureok = 1

# This command should fail with errors about missing tiles
command += oiiotool("src/partial.exr -d uint8 -o error.tif")
command += oiiotool("-iconfig oiio:missingcolor \"-1,0,0\" src/partial.exr -d uint8 -o missing.tif")

outputs = [ "missing.tif", "out.txt", "out.err.txt" ]



#!/usr/bin/env python 

# Test for oiiotool application of the Porter/Duff compositing operations
#


# test over
command += oiiotool ("src/a.exr --over src/b.exr -o a_over_b.exr")

# FIXME: no test for zover

# future: test in, out, etc., the other Porter/Duff operations

# Outputs to check against references
outputs = [ "a_over_b.exr", "out.txt" ]




#!/usr/bin/env python 

# Basic test -- save with dither
command += oiiotool ("-pattern fill:left=0,0,0:right=0.0625,0.0625,0.0625 256x256 3 -d uint8 -dither -o ramp.tif")

# Regression test for a buffer copy bug
command += oiiotool ("src/copybug-input.exr -ch R -dither -d uint8 -o bad.tif")

outputs = [ "ramp.tif", "bad.tif" ]



#!/usr/bin/env python

from __future__ import absolute_import
import shutil

# Make a copy called "misnamed.exr" that's actually a TIFF file
shutil.copyfile (OIIO_TESTSUITE_IMAGEDIR + "/grid.tif", "misnamed.exr")

# Now see if it is read correctly
command = info_command ("misnamed.exr")



#!/usr/bin/env python

import os
import shutil
import OpenImageIO as oiio

# Test OpenEXR's collection of damaged and broken images, to be sure
# we detect the damage and issue errors (not crash, etc).

failureok = True

# Save error output, too, and skip lines to make readable
redirect = ' >> out.txt 2>&1 '

# Figure out the version of openexr
openexr_version = 0
liblist = oiio.get_string_attribute("library_list").split(';')
for lib in liblist :
    lib_ver = lib.split(':')
    if lib_ver[0] == 'openexr' :
        ver = lib_ver[1].split(' ')[-1].split('.')
        openexr_version = int(ver[0]) * 10000 + int(ver[1]) * 100 + int(ver[2])
        print (openexr_version)


# ../openexr-images/Damaged:
# README   t03.exr  t06.exr  t09.exr  t12.exr  t15.exr
# t01.exr  t04.exr  t07.exr  t10.exr  t13.exr  t16.exr
# t02.exr  t05.exr  t08.exr  t11.exr  t14.exr
imagedir = OIIO_TESTSUITE_IMAGEDIR + "/Damaged"
files = [
"asan_heap-oob_4cb169_255_cc7ac9cde4b8634b31cb41c8fe89b92d_exr",
"asan_heap-oob_504235_131_78b0e15388401193e1ee2ce20fb7f3b0_exr",
"asan_heap-oob_7efd58fcbf3d_356_668b128c27c62e0d8314c503831fde88_exr",
"asan_heap-oob_7efd9bd346a5_639_9e0b30ed499cdf9e8802dd64e16a9508_exr",
"asan_heap-oob_7f09128c0ec1_358_ecaca7fb3f230d9d842074e1dd88f29b_exr",
"asan_heap-oob_7f0faa6bb393_900_7d9ed0a6eaa68f8308a042d725119ad2_exr",
"asan_heap-oob_7f11c0330393_935_240e7cacd61711daf4285366fea95e0c_exr",
"asan_heap-oob_7f11ece681f1_785_a570a0a25ada4752dabb554ad6b1eb6b_exr",
"asan_heap-oob_7f171b7ab3a2_937_b4e2415c399c2ab39548de911223769d_exr",
"asan_heap-oob_7f178ac80539_109_519f88e9ededfff61f535d6c9eb25a85_exr",
"asan_heap-oob_7f1fd65113ac_935_8fd55930e544dc3fb88659a6a8509c14_exr",
"asan_heap-oob_7f35311a1426_780_4871d40882e0fe7fae1427a82319e144_exr",
"asan_heap-oob_7f479f9536bd_391_5953693841a7931caf3d4592f8b9c90b_exr",
"asan_heap-oob_7f4aaebde389_918_a40f029a8121e5e26fe338b1fb91846e_exr",
"asan_heap-oob_7f4d5072b39d_561_5f5e4ef49a581edaf7bf0858fbfcfdd1_exr",
"asan_heap-oob_7f4f5558d00e_414_ec6445a8638a21c93ce8feb5a2e71981_exr",
"asan_heap-oob_7f54ed80df53_321_19490ab1841d3854eec557f3c23d0db0_exr",
"asan_heap-oob_7f5860f8d1f4_188_2e62008f8ecb3bb2ed67c09fa0939da7_exr",
"asan_heap-oob_7f58e8d75e8b_186_4bb7b1de93e9e44ea921c301b29a8026_exr",
"asan_heap-oob_7f5a5030cdca_702_045a76649e773c9c18b706c9853f18d9_exr",
"asan_heap-oob_7f5c18182f27_369_1fb4dae7654c77cd79646d3aa049d5dd_exr",
"asan_heap-oob_7f5cd523238e_878_03c277ec5021331fb301c7c1caa7dfd8_exr",
"asan_heap-oob_7f5cdab9a3a7_415_c33b838f08aafc976d3c24139936e122_exr",
"asan_heap-oob_7f6798416389_229_18bd946a4fde157b9974d16a51a4851d_exr",
"asan_heap-oob_7f6a78657cbf_916_10cc35387b54fdc7744f91b5bb424009_exr",
"asan_heap-oob_7f6e5e983398_203_ff7c0c73c79483db1fee001d77463c37_exr",
"asan_heap-oob_7f6efa7c53a7_991_4f9bd6fda4f5ae991775244b4945a7fb_exr",
"asan_heap-oob_7f6f881fa398_561_20ecb7f5a431d03a1502c28cab1214ad_exr",
"asan_heap-oob_7f730474b07c_543_fb506af38c88894d92ba0d433cf41abc_exr",
"asan_heap-oob_7f76b2c2cefb_196_ea4f8db8b4f2c11e02428c08e9bbbbb8_exr",
"asan_heap-oob_7f7a75f9abf5_577_a2b8668cc6069643543cb80fedca3ee4_exr",
"asan_heap-oob_7f8170c1abfa_115_8c6e33969541bf432ef7e68cc369728c_exr",
"asan_heap-oob_7f8a69d8339d_829_381ccc69dc6bd21c43a1deb0965bf5ab_exr",
"asan_heap-oob_7f8dd48421cd_321_7bae35650e908b12dbee1cf01e3d357f_exr",
"asan_heap-oob_7f8ed39ceed3_955_c6bb655a1bbfab9c5b511bd2b767e023_exr",
"asan_heap-oob_7f9acb068ee5_177_ec645ad270202d39ba5e80c826bbf13d_exr",
"asan_heap-oob_7f9cc08a96a5_942_e708072e479264a7808c055094a0fed9_exr",
"asan_heap-oob_7fa0e1f48cbf_760_be9901248390240a24449d4e8a97f6f2_exr",
"asan_heap-oob_7fa34eacd389_820_476a8109ebb3f7d02252e773b7bca45d_exr",
"asan_heap-oob_7faf9aba03ac_414_75af58c21b9b9e994747f9d6a5fc46d4_exr",
"asan_heap-oob_7fb3a7c6fc99_871_52d1f03c515bc91cc894515beea56a4f_exr",
"asan_heap-oob_7fb97d097381_293_78e73b6494a955e87faabcb16b35faa0_exr",
"asan_heap-oob_7fbe2d8e838e_932_9e9d2b0a870c0ad516189d274c2f98e4_exr",
"asan_heap-oob_7fc6b05f1eaf_255_e967badfa747d1bb0eda71a1883b419e_exr",
"asan_heap-oob_7fca10855564_529_6d418eae3e33a819185a8b09c40fd123_exr",
"asan_heap-oob_7fcdcb0a9f65_100_70d0d5b98567a5174d512dba7a603377_exr",
"asan_heap-oob_7fce901e7498_737_927b67c9a1ecd5f997d3a2620fdbf639_exr",
"asan_heap-oob_7fd328d0d206_535_9cc3d65c368fb138cb6a4bdd4da8070f_exr",
"asan_heap-oob_7fd921b41f11_369_da245dc772c0a5a60ce7b759b2132c51_exr",
"asan_heap-oob_7fdb9de0b38e_829_636ff2831c664e14a73282a3299781dd_exr",
"asan_heap-oob_7fe4c4caa975_277_153f78ec07237d01e8902143da28c7ec_exr",
"asan_heap-oob_7fe667eb33a2_999_31f64961e47968656f00573f7db5c67d_exr",
"asan_heap-oob_7fe814d1ce9d_617_e00af1c4c76b988122b68d43b073dd47_exr",
"asan_heap-oob_7ff4b88b21df_560_e119e0ba5bf9345e7daa85cc2fff6684_exr",
"asan_stack-oob_433d4f_157_4c56ecca982bc10e976527cd314bbcfa_exr",
"asan_stack-oob_433d4f_436_bb29e6f88ad5f5b2f5f9b68a3655b1d8_exr",
"asan_stack-oob_433d4f_510_f8d3ef49bd6e5f7ca4fb7e0f9c0af139_exr",
"openexr_2.2.0_heap_buffer_overflow_exr",
"openexr_2.2.0_memory_allocation_error_1_exr",
# "openexr_2.2.0_memory_allocation_error_2_exr",
"openexr_2.2.0_memory_allocation_error_3_exr",
"poc-099125d15685ef30feae813ddae15406b3f539d7cc4aa399176a50dcfe9be95c",
"poc-2b68475a090117f033df54c2de31546f7a1927ecadd9d0aa9b6bb8daad8ea971_min",
"poc-3e54bd90fc0e2a0b348ecd80d96738ed8324de388b3e88fd6c5fc666c2f01d83_min",
"poc-4d912f49ddc13ff49f95543880d47c85a8918e563fb723c340264f1719057613.mini",
"poc-66e4d1f68a3112b9aaa93831afbf8e283fd39be5e4591708bad917e6886c0ebb.mini",
"poc-89f7735a7cc9dcee59bfce4da70ad12e35a8809945b01b975d1a52ec15dbeccc",
"poc-9651abd6ee953b9f669db5927f8832f1b1eab028fa6ae7b4176a701aeea0ec90",
"poc-a905d63836959293bed720ab7d242bd07b7b7ec81ee3ee1e14e89853344dafbf_min",
"poc-af451a11e18ad9ca6ddc098bfd8b42f803bec2be8fafa6e648b8a7adcfdd0c06_min",
"poc-bd9579c640a6ee867d140c2a4d3bbd6f0452d4726f3f25ed53bf666f558ed245_min",
"poc-c9457552c1c04ea0f98154bc433a5f5d0421a7e705e6f396aba4339568473435_min",
"poc-cbc6ff03d6bc31f0c61476525641852b0220278e6576a651029c50e86f7f0c77",
"poc-d545cd0db4595a1c05504ab53d83cc8c6fce02387545aa49e979ee087c1ddf8f_min",
"poc-df1fefc5fb459cb12183eae34dc696cd0e77b0b8deb4cd1ef3dc25279b7a6bde_min",
"poc-e2106eebb303e685cee66860c931fe1a4eb9af1a7f5bef5b3b95f90c3e8ae0e0_min",
"poc-fb9238840f4d9d93ab3ac989b70000f9795ab6ad399bff00093b944e6a893403_min",
]

if openexr_version >= 20600 :
    files += [
        "signal_sigsegv_7ffff7b21e8a_389_bf048bf41ca71b4e00d2b0edd0a39e27_exr",
    ]


# Need to copy the files to a temp location to add a true .exr suffix
if not os.path.exists('tmpsrc'):
    os.mkdir('tmpsrc')



for f in files:
    # First, do a simple read/write loop to test ordinary ImageInput
    shutil.copyfile(os.path.join(imagedir, f),
                    os.path.join('tmpsrc', f+'.exr'))
    command += oiiotool ('-n -info tmpsrc/'+f+'.exr -o out.exr')
    command += '; echo >> out.txt \n'



#!/usr/bin/env python

imagedir = OIIO_TESTSUITE_IMAGEDIR + "/pnm"

# We can't yet write PFM files, so just get the hashes and call it a day
files = [ "test-1.pfm", "test-2.pfm", "test-3.pfm" ]
for f in files:
    command += info_command (imagedir + "/" + f,
                             safematch=True, hash=True)



#!/usr/bin/env python

command = oiiotool ("-pattern fill:topleft=0,0,0:topright=1,0,0:bottomleft=0,1,0:bottomright=1,1,1 "
                    + "64x64 3 -otex gradient.tx")
command += testtex_command ("gradient.tx",
                           "-flipt -nowarp -derivs -res 64 64 -d half -o out.exr")
outputs = [ "out.exr" ]



#!/usr/bin/env python 

# Construct a command that will create a texture, appending console
# output to the file "out.txt".
def omaketx_command (infile, outfile, extraargs="",
                     options="", output_cmd="-otex",
                     showinfo=True, showinfo_extra="",
                     silent=False, concat=True) :
    command = (oiio_app("oiiotool") 
               + " " + oiio_relpath(infile,tmpdir) 
               + " " + extraargs
               + " " + output_cmd + options + " " + oiio_relpath(outfile,tmpdir) )
    if not silent :
        command += " >> out.txt"
    if concat:
        command += " ;\n"
    if showinfo:
        command += info_command (outfile, extraargs=showinfo_extra, safematch=1)
    return command



# location of oiio-images directory
oiio_images = OIIO_TESTSUITE_IMAGEDIR

# Just for simplicity, make a checkerboard with a solid alpha
command += oiiotool (" --pattern checker 128x128 4 --ch R,G,B,=1.0"
                     + " -d uint8 -o " + oiio_relpath("checker.tif") )

# Basic test - recreate the grid texture
command += omaketx_command (oiio_images + "/grid.tif", "grid.tx")

# Test --resize (to power of 2) with the grid, which is 1000x1000
command += omaketx_command (oiio_images + "/grid.tif", "grid-resize.tx",
                            options=":resize=1")

# Test -d to set output data type
command += omaketx_command ("checker.tif", "checker-uint16.tx",
                            "-d uint16")

# Test --ch to restrict the number of channels
command += omaketx_command ("checker.tif", "checker-1chan.tx",
                            "--ch 0")

# Test --tiles to set a non-default tile size
command += omaketx_command ("checker.tif", "checker-16x32tile.tx",
                            "--tile 16 32")

# Test --separate and --compression
command += omaketx_command ("checker.tif", "checker-seplzw.tx",
                             "--planarconfig separate --compression lzw")

# Test --wrap
command += omaketx_command ("checker.tif", "checker-clamp.tx",
                            options=":wrap=clamp")

# Test --swrap and --twrap
command += omaketx_command ("checker.tif", "checker-permir.tx",
                            options=":swrap=periodic:twrap=mirror")

# Test --nomipmap
command += omaketx_command ("checker.tif", "checker-nomip.tx",
                            options=":nomipmap=1")

# Test setting matrices
command += omaketx_command ("checker.tif", "checker-camera.tx",
                           "--attrib:type=matrix worldtocamera 1,0,0,0,0,2,0,0,0,0,1,0,0,0,0,1 " +
                           "--attrib:type=matrix worldtoscreen 3,0,0,0,0,3,0,0,0,0,3,0,1,2,3,1")

# Test --opaque-detect (should drop the alpha channel)
command += omaketx_command ("checker.tif", "checker-opaque.tx",
                            options=":opaque_detect=1")

# Test --monochrome-detect (first create a monochrome image)
command += oiiotool (" --pattern constant:color=.25,.25,.25 256x256 3 "
                    + " -d uint8 -o " + oiio_relpath("gray.tif"))
command += omaketx_command ("gray.tif", "gray-mono.tx",
                            options=":monochrome_detect=1")

# Test --monochrome-detect on something that is NOT monochrome
command += oiiotool (" --pattern constant:color=.25,.2,.15 256x256 3 "
                    + " -d uint8 -o " + oiio_relpath("pink.tif"))
command += omaketx_command ("pink.tif", "pink-mono.tx",
                            options=":monochrome_detect=1")

# Test --prman : should save 'separate' planarconfig, and funny 64x32 tiles
# since we are specifying 16 bits, and it should save as 'int16' even though
# we asked for unsigned.
command += omaketx_command ("checker.tif", "checker-prman.tx",
                           "-d uint16", options=":prman=1")

# Test --fixnan : take advantage of the bad.exr images in 
# testsuite/oiiotool-fixnan.  (Use --nomipmap to cut down on stats output)
# FIXME: would also like to test --checknan, but the problem with that is
# that is actually FAILS if there's a nan.
command += omaketx_command (OIIO_TESTSUITE_ROOT+"/oiiotool-fixnan/src/bad.exr", "nan.exr",
                            "--fixnan box3", options=":nomipmap=1",
                            showinfo=True, showinfo_extra="--stats")

# Test that when outputting half textures, we clamp large float values
# rather than inadvertetly turning into Inf in the process of output to
# half.
command += oiiotool (" --pattern constant:color=1.0e6,1.0e6,1.0e6 2x2 3 -d float -o million.tif")
command += omaketx_command ("million.tif", "bigval.exr",
                            "-d half", showinfo_extra="--stats")

# Test --format to force exr even though it can't be deduced from the name.
command += omaketx_command ("checker.tif", "checker-exr.pdq",
                            options=":fileformatname=exr")

# Test that the oiio:SHA-1 hash is stable, and that that changing filter and
# using -hicomp result in different images and different hashes.
command += omaketx_command (oiio_images + "/grid.tif", "grid-lanczos3.tx",
                           options = ":filter=lanczos3", showinfo=False)
command += omaketx_command (oiio_images + "/grid.tif", "grid-lanczos3-hicomp.tx",
                           options = ":filter=lanczos3:highlightcomp=1", showinfo=False)
command += info_command ("grid.tx",
                         extraargs="--metamatch oiio:SHA-1")
command += info_command ("grid-lanczos3.tx",
                         extraargs="--metamatch oiio:SHA-1")
command += info_command ("grid-lanczos3-hicomp.tx",
                         extraargs="--metamatch oiio:SHA-1")

# Test that we cleanly replace any existing SHA-1 hash and ConstantColor
# hint in the ImageDescription of the input file.
command += oiiotool (" --pattern constant:color=1,0,0 64x64 3 "
            + " --caption \"foo SHA-1=1234abcd ConstantColor=[0.0,0,-0.0] bar\""
            + " -d uint8 -o " + oiio_relpath("small.tif") )
command += info_command ("small.tif", safematch=1);
command += omaketx_command ("small.tif", "small.tx",
                            options=":oiio=1:constant_color_detect=1")

# Regression test -- at one point, we had a bug where we were botching
# the poles of OpenEXR env maps, adding energy.  Check it by creating an
# all-white image, turning it into an env map, and calculating its
# statistics (should be 1.0 everywhere).
command += oiiotool (" --pattern constant:color=1,1,1 4x2 3 "
            + " -d half -o " + oiio_relpath("white.exr"))
command += omaketx_command ("white.exr", "whiteenv.exr",
                            output_cmd="-oenv", showinfo=False)
command += oiiotool ("--stats whiteenv.exr")

command += oiiotool (" --pattern noise 64x64 1"
            + " -d half -o " + oiio_relpath("bump.exr"))
command += omaketx_command ("bump.exr", "bumpslope.exr",
                            extraargs="-d half",
                            output_cmd="-obump", showinfo=False)
command += oiiotool ("--stats bumpslope.exr")


outputs = [ "out.txt" ]



# To do:  --filter --checknan --fullpixels
#         --prman-metadata --ignore-unassoc
#         --mipimage 
#         --envlatl TIFF, --envlatl EXR
#         --colorconvert --unpremult -u --fovcot



#!/usr/bin/env python

# This test verifies that the TextureSystem is sampling the correct
# MIPmap levels given the input derivatives.
#
# It uses 'testtex --filtertest', which produces an image where each
# pixel samples at the center of the source image, and keeps the minor
# axis of the filter at 1/256, but we vary the eccentricity (i.e. major
# axis length) as we go left (1) to right (32), and vary the angle as we
# go top (0) to bottom (2pi).
#
# If filtering is correct, all pixels should sample from the same MIP
# level because they have the same minor axis (1/256), regardless of
# eccentricity or angle.  If we specify a texture that has a
# distinctive color at the 256-res level, and something totally
# different at the 512 and 128 levels, it should be easy to verify that
# we aren't over-filtering or under-filtering.
#
# And, hey, we have such a texture: ../oiio-images/miplevels.tx.  This
# image is all green (except for black "256" text) on the 256-res level,
# all red at the 512 level (except for black "512" text), and all blue
# at the 128 level (except for black "128" text).  So, a correct
# behavior for this test will be to have an all-green appearance.  If
# there is any pulling in texels from other MIP levels, you will see
# non-zero blue or red channel values.  Note that we do expect the green
# level to vary a bit, because some angles and filter major axis sizes
# will pull in some of the black of the "256" text.  That's ok.  The
# important thing is no red or blue (beyond minuscule amounts that would
# be due to acceptable numerical errors in the filter estimation).
#
# Caveat: There are other kind of errors possible, not detected by this
# test.  It could be getting the eccentricity or angle wrong. But those
# errors would only affect grazing angles, it wouldn't give people the
# impression that texture was too blurry everywhere. With this test, we
# can at least be sure that our basic MIPmap level selection is dead-on.



command = testtex_command (OIIO_TESTSUITE_IMAGEDIR + "/miplevels.tx",
                           " --filtertest -res 256 256 -d uint8 -o out.tif")
outputs = [ "out.tif" ]



#!/usr/bin/env python

command = (oiio_app("testtex") + " -res 256 256 "
           + "-texoptions max_mip_res=128 "
           + OIIO_TESTSUITE_IMAGEDIR + "/miplevels.tx"
           + " -d uint8 -o out.tif ;\n")

outputs = [ "out.tif", "out.txt" ]



#!/usr/bin/env python

# This file has a corrupted Exif block in the metadata. It used to
# crash on some platforms, on others would be caught by address sanitizer.
# Fixed by #1635. This test serves to guard against regressions.
command += info_command ("src/corrupt-exif.jpg", safematch=True)

# Checking the error output is important for this test
outputs = [ "out.txt" ]
failureok = 1



#!/usr/bin/env python

# ../openexr-images/ScanLines:
# Blobbies.exr     Cannon.exr  MtTamWest.exr     StillLife.exr
# CandleGlass.exr  Desk.exr    PrismsLenses.exr  Tree.exr
imagedir = OIIO_TESTSUITE_IMAGEDIR + "/ScanLines"
files = [ "Desk.exr", "MtTamWest.exr" ]
files = [
    "Blobbies.exr", "CandleGlass.exr", "Cannon.exr", "Desk.exr",
    "MtTamWest.exr", "PrismsLenses.exr", "StillLife.exr", "Tree.exr"
]
for f in files:
    command += rw_command (imagedir, f)


# ../openexr-images/TestImages:
# AllHalfValues.exr        GrayRampsDiagonal.exr    SquaresSwirls.exr
# BrightRings.exr          GrayRampsHorizontal.exr  WideColorGamut.exr
# BrightRingsNanInf.exr    README                   WideFloatRange.exr
# GammaChart.exr           RgbRampsDiagonal.exr
imagedir = OIIO_TESTSUITE_IMAGEDIR + "/TestImages"
files = [ "AllHalfValues.exr", "BrightRings.exr", "BrightRingsNanInf.exr",
          "GammaChart.exr", "GrayRampsDiagonal.exr",
          "GrayRampsHorizontal.exr", "RgbRampsDiagonal.exr",
          "SquaresSwirls.exr", "WideColorGamut.exr", "WideFloatRange.exr" ]
for f in files:
    command += rw_command (imagedir, f)


# ../openexr-images/Tiles:
# GoldenGate.exr  Ocean.exr       Spirals.exr
imagedir = OIIO_TESTSUITE_IMAGEDIR + "/Tiles"
files = [ "GoldenGate.exr", "Ocean.exr", "Spirals.exr" ]
for f in files:
    command += rw_command (imagedir, f)


# Check a complicated channel and layer ordering example
imagedir = OIIO_TESTSUITE_IMAGEDIR + "/Beachball"
files = [ "singlepart.0001.exr" ]
for f in files:
    command += rw_command (imagedir, f)



#!/usr/bin/env python

from __future__ import print_function
from __future__ import absolute_import
import OpenImageIO as oiio
import os

OIIO_TESTSUITE_IMAGEDIR = os.getenv('OIIO_TESTSUITE_IMAGEDIR',
                                    '../../../../../oiio-images')

# Print the contents of an ImageSpec
def print_imagespec (spec, subimage=0, mip=0, msg="") :
    if msg != "" :
        print (str(msg))
    if spec.depth <= 1 :
        print ("  resolution %dx%d%+d%+d" % (spec.width, spec.height, spec.x, spec.y))
    else :
        print ("  resolution %dx%d%x%d+d%+d%+d" % (spec.width, spec.height, spec.depth, spec.x, spec.y, spec.z))
    if (spec.width != spec.full_width or spec.height != spec.full_height
        or spec.depth != spec.full_depth) :
        if spec.full_depth <= 1 :
            print ("  full res   %dx%d%+d%+d" % (spec.full_width, spec.full_height, spec.full_x, spec.full_y))
        else :
            print ("  full res   %dx%d%x%d+d%+d%+d" % (spec.full_width, spec.full_height, spec.full_depth, spec.full_x, spec.full_y, spec.full_z))
    if spec.tile_width :
        print ("  tile size  %dx%dx%d" % (spec.tile_width, spec.tile_height, spec.tile_depth))
    else :
        print ("  untiled")
    if mip >= 1 :
        return
    print ("  " + str(spec.nchannels), "channels:", spec.channelnames)
    print ("  format = ", str(spec.format))
    if spec.channelformats :
        print ("  channelformats = ", spec.channelformats)
    print ("  alpha channel = ", spec.alpha_channel)
    print ("  z channel = ", spec.z_channel)
    print ("  deep = ", spec.deep)
    for i in range(len(spec.extra_attribs)) :
        if type(spec.extra_attribs[i].value) == str :
            print (" ", spec.extra_attribs[i].name, "= \"" + spec.extra_attribs[i].value + "\"")
        else :
            print (" ", spec.extra_attribs[i].name, "=", spec.extra_attribs[i].value)



def poor_mans_iinfo (filename) :
    input = oiio.ImageInput.open (filename)
    if not input :
        print ('Could not open "' + filename + '"')
        print ("\tError: ", oiio.geterror())
        return
    print ('Opened "' + filename + '" as a ' + input.format_name())
    sub = 0
    mip = 0
    while True :
        if sub > 0 or mip > 0 :
            print ("Subimage", sub, "MIP level", mip, ":")
        print_imagespec (input.spec(), mip=mip)
        mip = mip + 1
        if input.seek_subimage (sub, mip) :
            continue    # proceed to next MIP level
        else :
            sub = sub + 1
            mip = 0
            if input.seek_subimage (sub, mip) :
                continue    # proceed to next subimage
        break  # no more MIP levels or subimages
    input.close ()
    print ()



# Read the whole image (using either read_image, read_scanlines, or
# read_tiles, depending on the 'method' argument) and print a few 
# pixel values ot prove that we have the right data. Read nchannels
# channels, if nonzero, otherwise read the full channel range in the
# file.
def test_readimage (filename, sub=0, mip=0, type=oiio.UNKNOWN,
                    method="image", nchannels=0,
                    print_pixels = True, keep_unknown=False) :
    input = oiio.ImageInput.open (filename)
    if not input :
        print ('Could not open "' + filename + '"')
        print ("\tError: ", oiio.geterror())
        print ()
        return
    print ('Opened "' + filename + '" as a ' + input.format_name())
    input.seek_subimage (sub, mip)
    spec = input.spec ()
    if nchannels == 0 or method == "image" :
        nchannels = spec.nchannels
    if str(type) == "unknown" and not keep_unknown :
        type = spec.format.basetype
    if method == "image" :
        data = input.read_image (type)
    elif method == "scanlines" :
        data = input.read_scanlines (spec.y, spec.y+spec.height, spec.z,
                                     0, nchannels, type)
    elif method == "tiles" :
        data = input.read_tiles (spec.x, spec.x+spec.width,
                                 spec.y, spec.y+spec.height,
                                 spec.z, spec.z+spec.depth,
                                 0, nchannels, type)
    else :
        print ("Unknown method:", method)
        return
    if data is None :
        print ("read returned None")
        return
    if print_pixels :
        # print the first, last, and middle pixel values
        (x,y) = (spec.x, spec.y)
        print ("@", (x,y), "=", data[y,x])
        (x,y) = (spec.x+spec.width-1, spec.y+spec.height-1)
        print ("@", (x,y), "=", data[y,x])
        (x,y) = (spec.x+spec.width//2, spec.y+spec.height//2)
        print ("@", (x,y), "=", data[y,x])
    else :
        print ("Read array typecode", data.dtype, " [", data.size, "]")
    # Test the spec and spec_dimensions methods
    spec = input.spec_dimensions (0, 0)
    if len(spec.extra_attribs) > 0 :
        print ("wrong spec_dimensions(s,m) metadata items: ", len(spec.extra_attribs))
    spec = input.spec (0, 0)
    if len(spec.extra_attribs) == 0 :
        print ("wrong spec(s,m) metadata items: ", len(spec.extra_attribs))
    input.close ()
    print ()



# Read the image, one scanline at a time, print a couple values
# at particular locations to make sure we have the correct data.
def test_readscanline (filename, sub=0, mip=0, type=oiio.UNKNOWN) :
    input = oiio.ImageInput.open (filename)
    if not input :
        print ('Could not open "' + filename + '"')
        print ("\tError: ", oiio.geterror())
        print ()
        return
    print ('Opened "' + filename + '" as a ' + input.format_name())
    input.seek_subimage (sub, mip)
    spec = input.spec ()
    if spec.tile_width != 0 :
        print ("Error: tiled")
        return
    if type == oiio.UNKNOWN :
        type = spec.format.basetype
    for y in range(spec.height) :
        data = input.read_scanline (y+spec.y, spec.z, type)
        if data is None :
            print ("read returned None")
            return
        # print the first pixel of the first and last scanline
        if y == 0 or y == (spec.height-1) :
            print ("@", (spec.x,y+spec.y), "=", data[0])
    input.close ()
    print ()



# Read the whole image, one tile at a time, print a couple values
# at particular locations to make sure we have the correct data.
def test_readtile (filename, sub=0, mip=0, type=oiio.UNKNOWN) :
    input = oiio.ImageInput.open (filename)
    if not input :
        print ('Could not open "' + filename + '"')
        print ("\tError: ", oiio.geterror())
        print ()
        return
    print ('Opened "' + filename + '" as a ' + input.format_name())
    input.seek_subimage (sub, mip)
    spec = input.spec ()
    if spec.tile_width == 0 :
        print ("Error: not tiled")
        return
    if type == oiio.UNKNOWN :
        type = spec.format.basetype
    # Randomly read a couple of tiles, print a pixel from within it
    (tx,ty) = (spec.x, spec.y)
    data = input.read_tile (tx+spec.x, ty+spec.y, spec.z, type)
    if data is None :
        print ("read returned None")
        return
    (x,y) = (tx+spec.tile_width//2, ty+spec.tile_height//2)
    print ("@", (x,y), "=", data[y,x])
    (tx,ty) = (spec.x+2*spec.tile_width, spec.y+2*spec.tile_height)
    data = input.read_tile (tx+spec.x, ty+spec.y, spec.z, type)
    print ("@", (x,y), "=", data[y,x])
    input.close ()
    print ()


def write (image, filename, format=oiio.UNKNOWN) :
    if not image.has_error :
        image.set_write_format (format)
        image.write (filename)
    if image.has_error :
        print ("Error writing", filename, ":", image.geterror())


# Regression test for #2285: configuration settings were "forgotten" if the
# scanline read order necessitated closing and reopening the file.
def test_tiff_remembering_config() :
    # Create a file that has unassociated alpha
    print ("Testing write and read of unassociated:")
    spec = oiio.ImageSpec(2,2,4,"float")
    spec.attribute("oiio:UnassociatedAlpha", 1)
    wbuf = oiio.ImageBuf(spec)
    oiio.ImageBufAlgo.fill(wbuf, (0.5, 0.5, 0.5, 0.5))
    print ("  writing: ", wbuf.get_pixels())
    wbuf.write("test_unassoc.tif")
    rbuf = oiio.ImageBuf("test_unassoc.tif")
    print ("\n  default reading as IB: ", rbuf.get_pixels())
    config = oiio.ImageSpec()
    config.attribute("oiio:UnassociatedAlpha", 1)
    rbuf = oiio.ImageBuf("test_unassoc.tif", 0, 0, config)
    print ("\n  reading as IB with unassoc hint: ", rbuf.get_pixels())
    print ("\n  reading as II with hint, read scanlines backward: ")
    ii = oiio.ImageInput.open("test_unassoc.tif", config)
    print ("    [1] = ", ii.read_scanline(1))
    print ("    [0] = ", ii.read_scanline(0))
    print ("\n")

# Regression test for #2292: make sure that TIFF cmyk files with RGB
# translation, when read backwards, is ok.
def test_tiff_cmyk() :
    # Create a file that has unassociated alpha
    filename = "test_cmyk.tif"
    print ("Testing write and read of TIFF CMYK with auto RGB translation:")
    spec = oiio.ImageSpec(2,2,4,"uint8")
    spec.attribute("tiff:ColorSpace", "CMYK")
    spec.channelnames = ("C", "M", "Y", "K")
    wbuf = oiio.ImageBuf(spec)
    oiio.ImageBufAlgo.fill(wbuf, (0.5, 0.0, 0.0, 0.5))
    print ("  writing: ", wbuf.get_pixels())
    wbuf.write(filename)
    rbuf = oiio.ImageBuf(filename)
    print ("\n  default reading as IB: ", rbuf.get_pixels())
    config = oiio.ImageSpec()
    config.attribute("oiio:RawColor", 1)
    rbuf = oiio.ImageBuf(filename, 0, 0, config)
    print ("\n  reading as IB with rawcolor=1: ", rbuf.get_pixels())
    print ("\n  reading as II with rawcolor=0, read scanlines backward: ")
    ii = oiio.ImageInput.open(filename)
    print ("    [1] = ", ii.read_scanline(1))
    print ("    [0] = ", ii.read_scanline(0))
    print ("\n")




######################################################################
# main test starts here

try:
    # test basic opening and being able to read the spec
    poor_mans_iinfo ("badname.tif")
    poor_mans_iinfo (OIIO_TESTSUITE_IMAGEDIR + "/tahoe-gps.jpg")
    poor_mans_iinfo ("grid.tx")

    # test readimage
    print ("Testing read_image:")
    test_readimage (OIIO_TESTSUITE_IMAGEDIR + "/tahoe-gps.jpg")
    # again, force a float buffer
    test_readimage (OIIO_TESTSUITE_IMAGEDIR + "/tahoe-gps.jpg",
                    type=oiio.FLOAT)
    # Test read of partial channels
    test_readimage (OIIO_TESTSUITE_IMAGEDIR + "/tahoe-gps.jpg",
                    method="scanlines", nchannels=1)

    # test readscanline
    print ("Testing read_scanline:")
    test_readscanline (OIIO_TESTSUITE_IMAGEDIR + "/tahoe-gps.jpg")

    # test readtile
    print ("Testing read_tile:")
    test_readtile ("grid.tx")

    # test readscanlines
    print ("Testing read_scanlines:")
    test_readimage (OIIO_TESTSUITE_IMAGEDIR + "/tahoe-gps.jpg",
                    method="scanlines")

    # test readtiles
    print ("Testing read_tiles:")
    test_readimage ("grid.tx",
                    method="tiles")

    # test reading a raw buffer in native format, we should get back
    # an unsigned byte array.
    b = oiio.ImageBuf (oiio.ImageSpec(64, 64, 3, oiio.UINT16))
    oiio.ImageBufAlgo.fill (b, (1,0,0), (0,1,0), (0,0,1), (1,1,1))
    write (b, "testu16.tif", oiio.UINT16)
    b.set_write_tiles (32, 32)
    write (b, "testf16.exr", oiio.HALF)
    print ("Test read_image native u16:")
    test_readimage ("testu16.tif", method="image", type=oiio.UNKNOWN,
                    keep_unknown=True, print_pixels=False)
    print ("Test read_scanlines native u16:")
    test_readimage ("testu16.tif", method="scanlines", type=oiio.UNKNOWN,
                    keep_unknown=True, print_pixels=False)
    print ("Test read_tiles native half:")
    test_readimage ("testf16.exr", method="tiles", type=oiio.UNKNOWN,
                    keep_unknown=True, print_pixels=False)
    print ("Test read_image into half:")
    test_readimage ("testu16.tif", method="image", type=oiio.HALF,
                    keep_unknown=True, print_pixels=False)
    print ("Test read_image into FLOAT:")
    test_readimage ("testu16.tif", method="image", type="float",
                    keep_unknown=True, print_pixels=False)

    test_tiff_remembering_config()
    test_tiff_cmyk()

    # Test is_imageio_format_name
    print ("is_imageio_format_name('tiff') =", oiio.is_imageio_format_name('tiff'))
    print ("is_imageio_format_name('txff') =", oiio.is_imageio_format_name('txff'))

    print ("Done.")
except Exception as detail:
    print ("Unknown exception:", detail)




#!/usr/bin/env python

# test 1: seed top level, no MIP map
command += testtex_command (OIIO_TESTSUITE_IMAGEDIR + " -res 256 256 -d uint8 -o out1.tif --testicwrite 1 blah")
# test 2: seed top level, automip
command += testtex_command (OIIO_TESTSUITE_IMAGEDIR + " -res 256 256 -d uint8 -o out2.tif --testicwrite 1 --automip blah")

# test 3: procedural MIP map
command += testtex_command (OIIO_TESTSUITE_IMAGEDIR + " -res 256 256 -d uint8 -o out3.tif --testicwrite 2 blah")
# test 4: procedural top level, automip
command += testtex_command (OIIO_TESTSUITE_IMAGEDIR + " -res 256 256 -d uint8 -o out4.tif --testicwrite 2 --automip blah")

outputs = [ "out1.tif", "out2.tif", "out3.tif", "out4.tif" ]



#!/usr/bin/env python 

exrdir = OIIO_TESTSUITE_IMAGEDIR + "/v2/LowResLeftView"

# test --flatten : turn deep into composited non-deep
command += oiiotool("src/deepalpha.exr --flatten -o flat.exr")

# test --ch on deep files (and --chnames)
command += oiiotool("src/deepalpha.exr --ch =0.0,A,=0.5,A,Z --chnames R,G,B,A,Z --flatten -d half -o ch.exr")

# --deepen
command += oiiotool("-pattern fill:topleft=0,14:topright=0.5,15:bottomleft=0.5,14:bottomright=1,15 4x4 2 -chnames A,Z -fill:color=0,1e38 2x1+1+2 -o az.exr")
command += oiiotool("az.exr -deepen -o deepen.exr")

# --crop deep images
command += oiiotool("deepen.exr -crop 2x2+1+1 -o crop1.exr")
command += oiiotool("deepen.exr -crop 5x5+1+1 -o crop2.exr")

# --trim
command += oiiotool("crop2.exr -trim -o trim1.exr")
command += oiiotool("-autotrim crop2.exr -o trim2.exr")

# --addc
command += oiiotool("src/deepalpha.exr -addc 0,10 -crop 160x100 -o deep_addc.exr")
# --subc
command += oiiotool("src/deepalpha.exr -subc 0,-1 -crop 160x105 -o deep_subc.exr")
# --mulc
command += oiiotool("src/deepalpha.exr -mulc 1,10 -crop 160x110 -o deep_mulc.exr")
# --divc
command += oiiotool("src/deepalpha.exr -divc 1,2 -crop 160x115 -o deep_divc.exr")

# --deepmerge
command += oiiotool (exrdir+"/Balls.exr -cut 512x288+0+0 " +
                     exrdir+"/Ground.exr -cut 512x288+0+0 " +
                     exrdir+"/Leaves.exr -cut 512x288+0+0 " +
                     exrdir+"/Trunks.exr -cut 512x288+0+0 " +
                     " -deepmerge -deepmerge -deepmerge -flatten " +
                     " -ch R,G,B,A -d half -o deepmerge.exr")

# --resample
command += oiiotool (exrdir+"/Balls.exr -resample 128x72 -o resampled-balls.exr")



# Regression test: it used to be that comparing deep image, it would loop
# only over A's samples, so if A had no samples in a pixel but B had
# samples, then the comparison would fail to see a difference. Be sure to
# test both orderings.
# Compare with both orderings
command += oiiotool ("--fail 100 src/deep-nosamples.exr src/deep-onesample.exr --diff")
command += oiiotool ("--fail 100 src/deep-onesample.exr src/deep-nosamples.exr --diff")
 # Recipe for creating the files:
 # spec = oiio.ImageSpec (1, 1, 1, oiio.TypeDesc.TypeFloat)
 # spec.channelnames = ("Z")
 # spec.deep = True
 # buf = oiio.ImageBuf (spec)
 # buf.write ("src/deep-nosamples.exr")  # write a deep image with no samples
 # buf.set_deep_samples (0, 0, 0, 1)
 # buf.set_deep_value (0, 0, 0, 0, 0, 42.0)
 # buf.write ("src/deep-onesample.exr")  # write another deep image with 1 sample


# To add more tests, just append more lines like the above and also add
# the new 'feature.tif' (or whatever you call it) to the outputs list,
# below.


# Outputs to check against references
outputs = [ "flat.exr",
            "ch.exr",
            "deepen.exr",
            "crop1.exr", "crop2.exr",
            "trim1.exr", "trim2.exr",
            "deep_addc.exr",
            "deep_subc.exr",
            "deep_mulc.exr",
            "deep_divc.exr",
            "deepmerge.exr",
            "resampled-balls.exr",
            "out.txt" ]

#print "Running this command:\n" + command + "\n"



#!/usr/bin/env python 

# This test renders the "tube" pattern with a checker pattern (i.e.,
# showing all angles and a wide range of anisotropy), at several
# different blur levels.

grid = "../common/textures/grid.tx"
checker = "../common/textures/checker.tx"

command += testtex_command (grid, "--tube --blur 0.0 -d uint8 -o grid-0.00.tif")
command += testtex_command (grid, "--tube --blur 0.02 -d uint8 -o grid-0.02.tif")
command += testtex_command (grid, "--tube --blur 0.05 -d uint8 -o grid-0.05.tif")
command += testtex_command (grid, "--tube --blur 0.1 -d uint8 -o grid-0.10.tif")
command += testtex_command (grid, "--tube --blur 0.2 -d uint8 -o grid-0.20.tif")
outputs = [ "grid-0.00.tif", "grid-0.02.tif", "grid-0.05.tif",
            "grid-0.10.tif", "grid-0.20.tif" ]


command += testtex_command (checker, "--tube --blur 0.0 -d uint8 -o checker-0.00.tif")
command += testtex_command (checker, "--tube --blur 0.02 -d uint8 -o checker-0.02.tif")
command += testtex_command (checker, "--tube --blur 0.05 -d uint8 -o checker-0.05.tif")
command += testtex_command (checker, "--tube --blur 0.1 -d uint8 -o checker-0.10.tif")
command += testtex_command (checker, "--tube --blur 0.2 -d uint8 -o checker-0.20.tif")
outputs += [ "checker-0.00.tif", "checker-0.02.tif", "checker-0.05.tif",
             "checker-0.10.tif", "checker-0.20.tif" ]



#!/usr/bin/env python

# This tests a particular tricky case: the interplay of "black" wrap mode
# with fill color.  Outside the s,t [0,1] range, it should be black, NOT
# fill color.  

# Make an RGB grid for our test
command += (oiio_app("oiiotool")
            + OIIO_TESTSUITE_IMAGEDIR + "/grid.tif"
            + " -ch R,G,B -o grid3.tif >> out.txt ;\n")

# And a 1-channel grid for our test
command += (oiio_app("oiiotool")
            + OIIO_TESTSUITE_IMAGEDIR + "/grid.tif"
            + " -ch R -o grid1.tif >> out.txt ;\n")

command += testtex_command ("grid3.tif",
                            " -res 256 256 -automip " +
                            " -wrap black -fill 0.5 -d uint8 -o out3.tif")

command += testtex_command ("grid1.tif",
                            " -res 200 200 -automip --graytorgb " +
                            " -wrap black -fill 0.5 -d uint8 -o out1.tif")

outputs = [ "out3.tif", "out1.tif" ]



#!/usr/bin/env python 

command += oiiotool ("src/bad.exr --fixnan black -o black.exr")
command += oiiotool ("src/bad.exr --fixnan box3 -o box3.exr")
command += info_command ("src/bad.exr", "--stats", safematch=True)
command += info_command ("black.exr", "--stats", safematch=True)
command += info_command ("box3.exr", "--stats", safematch=True)

# Outputs to check against references
outputs = [ "black.exr", "box3.exr", "out.txt" ]



#!/usr/bin/env python

from __future__ import print_function
from __future__ import absolute_import
import os
import glob
import sys
import platform
import subprocess
import difflib
import filecmp
import shutil

from optparse import OptionParser


#
# Get standard testsuite test arguments: srcdir exepath
#

srcdir = "."
tmpdir = "."
path = "../.."

# Options for the command line
parser = OptionParser()
parser.add_option("-p", "--path", help="add to executable path",
                  action="store", type="string", dest="path", default="")
parser.add_option("--devenv-config", help="use a MS Visual Studio configuration",
                  action="store", type="string", dest="devenv_config", default="")
parser.add_option("--solution-path", help="MS Visual Studio solution path",
                  action="store", type="string", dest="solution_path", default="")
(options, args) = parser.parse_args()

if args and len(args) > 0 :
    srcdir = args[0]
    srcdir = os.path.abspath (srcdir) + "/"
    os.chdir (srcdir)
if args and len(args) > 1 :
    path = args[1]
path = os.path.normpath (path)

tmpdir = "."
tmpdir = os.path.abspath (tmpdir)
redirect = " >> out.txt "

def oiio_relpath (path, start=os.curdir):
    "Wrapper around os.path.relpath which always uses '/' as the separator."
    p = os.path.relpath (path, start)
    return p if platform.system() != 'Windows' else p.replace ('\\', '/')

# Try to figure out where some key things are. Go by env variables set by
# the cmake tests, but if those aren't set, assume somebody is running
# this script by hand from inside build/PLATFORM/testsuite/TEST and that
# the rest of the tree has the standard layout.
OIIO_TESTSUITE_ROOT = oiio_relpath(os.getenv('OIIO_TESTSUITE_ROOT',
                                             '../../../../testsuite'))
OIIO_TESTSUITE_IMAGEDIR = os.getenv('OIIO_TESTSUITE_IMAGEDIR',
                                    '../../../../../oiio-images')
if OIIO_TESTSUITE_IMAGEDIR:
    OIIO_TESTSUITE_IMAGEDIR = oiio_relpath(OIIO_TESTSUITE_IMAGEDIR)
    # Set it back so test's can use it (python-imagebufalgo)
    os.putenv('OIIO_TESTSUITE_IMAGEDIR', OIIO_TESTSUITE_IMAGEDIR)
refdir = "ref/"
refdirlist = [ refdir ]
mytest = os.path.split(os.path.abspath(os.getcwd()))[-1]
if str(mytest).endswith('.batch') :
    mytest = mytest.split('.')[0]
test_source_dir = os.getenv('OIIO_TESTSUITE_SRC',
                            os.path.join(OIIO_TESTSUITE_ROOT, mytest))
colorconfig_file = os.path.join(OIIO_TESTSUITE_ROOT,
                                "common", "OpenColorIO", "nuke-default", "config.ocio")

# Swap the relative diff lines if the test suite is not being run via Makefile
if OIIO_TESTSUITE_ROOT != "../../../../testsuite":
    def replace_relative(lines):
        imgdir = None
        if OIIO_TESTSUITE_IMAGEDIR:
            imgdir = os.path.basename(OIIO_TESTSUITE_IMAGEDIR)
            if imgdir != "oiio-images":
                oiioimgs = os.path.basename(os.path.dirname(OIIO_TESTSUITE_IMAGEDIR))
                if oiioimgs == "oiio-images":
                    imgdir = "oiio-images/" + imgdir
                imgdir = "../../../../../" + imgdir

        for i in range(len(lines)):
            lines[i] = lines[i].replace("../../../../testsuite", OIIO_TESTSUITE_ROOT)
            if imgdir:
                lines[i] = lines[i].replace(imgdir, OIIO_TESTSUITE_IMAGEDIR)
        return lines
else:
    replace_relative = None


command = ""
outputs = [ "out.txt" ]    # default
failureok = 0
failthresh = 0.004
hardfail = 0.012
failpercent = 0.02
anymatch = False
cleanup_on_success = False
if int(os.getenv('TESTSUITE_CLEANUP_ON_SUCCESS', '0')) :
    cleanup_on_success = True

image_extensions = [ ".tif", ".tx", ".exr", ".jpg", ".png", ".rla",
                     ".dpx", ".iff", ".psd", ".bmp", ".fits", ".ico",
                     ".jp2", ".sgi", ".tga", ".TGA", ".zfile" ]

# print ("srcdir = " + srcdir)
# print ("tmpdir = " + tmpdir)
# print ("path = " + path)
# print ("refdir = " + refdir)
# print ("test source dir = " + test_source_dir)

if platform.system() == 'Windows' :
    if not os.path.exists("./ref") :
        shutil.copytree (os.path.join (test_source_dir, "ref"), "./ref")
    if os.path.exists (os.path.join (test_source_dir, "src")) and not os.path.exists("./src") :
        shutil.copytree (os.path.join (test_source_dir, "src"), "./src")
    # if not os.path.exists("../data") :
    #     shutil.copytree ("../../../testsuite/data", "..")
    # if not os.path.exists("../common") :
    #     shutil.copytree ("../../../testsuite/common", "..")
else :
    def newsymlink(src, dst):
        print("newsymlink", src, dst)
        # os.path.exists returns False for broken symlinks, so remove if thats the case
        if os.path.islink(dst):
            os.remove(dst)
        os.symlink (src, dst)
    if not os.path.exists("./ref") :
        newsymlink (os.path.join (test_source_dir, "ref"), "./ref")
    if os.path.exists (os.path.join (test_source_dir, "src")) and not os.path.exists("./src") :
        newsymlink (os.path.join (test_source_dir, "src"), "./src")
    if not os.path.exists("./data") :
        newsymlink (test_source_dir, "./data")


if os.getenv("Python_EXECUTABLE") :
    pythonbin = os.getenv("Python_EXECUTABLE")
else :
    pythonbin = 'python'
    if os.getenv("PYTHON_VERSION") :
        pythonbin += os.getenv("PYTHON_VERSION")
#print ("pythonbin = ", pythonbin)


###########################################################################

# Handy functions...

# Compare two text files. Returns 0 if they are equal otherwise returns
# a non-zero value and writes the differences to "diff_file".
# Based on the command-line interface to difflib example from the Python
# documentation
def text_diff (fromfile, tofile, diff_file=None):
    import time
    try:
        fromdate = time.ctime (os.stat (fromfile).st_mtime)
        todate = time.ctime (os.stat (tofile).st_mtime)
        fromlines = open (fromfile, 'r').readlines()
        tolines   = open (tofile, 'r').readlines()
        if replace_relative:
            tolines = replace_relative(tolines)
    except:
        print ("Unexpected error:", sys.exc_info()[0])
        return -1
        
    diff = difflib.unified_diff(fromlines, tolines, fromfile, tofile,
                                fromdate, todate)
    # Diff is a generator, but since we need a way to tell if it is
    # empty we just store all the text in advance
    diff_lines = [l for l in diff]
    if not diff_lines:
        return 0
    if diff_file:
        try:
            open (diff_file, 'w').writelines (diff_lines)

            print ("Diff " + fromfile + " vs " + tofile + " was:\n-------")
#            print (diff)
            print ("".join(diff_lines))
        except:
            print ("Unexpected error:", sys.exc_info()[0])
    return 1


def run_app(app, silent=False, concat=True):
    command = app
    if not silent:
        command += redirect
    if concat:
        command += " ;\n"
    return command

def oiio_app (app):
    if (platform.system () != 'Windows' or options.devenv_config == ""):
        return os.path.join (path, "bin", app) + " "
    else:
        return os.path.join (path, "bin", options.devenv_config, app) + " "


# Construct a command that will print info for an image, appending output to
# the file "out.txt".  If 'safematch' is nonzero, it will exclude printing
# of fields that tend to change from run to run or release to release.
def info_command (file, extraargs="", safematch=False, hash=True,
                  verbose=True) :
    args = "--info"
    if verbose :
        args += " -v -a"
    if safematch :
        args += " --no-metamatch \"DateTime|Software|OriginatingProgram|ImageHistory\""
    if hash :
        args += " --hash"
    return (oiio_app("oiiotool") + args + " " + extraargs
            + " " + oiio_relpath(file,tmpdir) + redirect + ";\n")


# Construct a command that will compare two images, appending output to
# the file "out.txt".  We allow a small number of pixels to have up to
# 1 LSB (8 bit) error, it's very hard to make different platforms and
# compilers always match to every last floating point bit.
def diff_command (fileA, fileB, extraargs="", silent=False, concat=True) :
    command = (oiio_app("idiff") + "-a"
               + " -fail " + str(failthresh)
               + " -failpercent " + str(failpercent)
               + " -hardfail " + str(hardfail)
               + " -warn " + str(2*failthresh)
               + " -warnpercent " + str(failpercent)
               + " " + extraargs + " " + oiio_relpath(fileA,tmpdir) 
               + " " + oiio_relpath(fileB,tmpdir))
    if not silent :
        command += redirect
    if concat:
        command += " ;\n"
    return command


# Construct a command that will create a texture, appending console
# output to the file "out.txt".
def maketx_command (infile, outfile, extraargs="",
                    showinfo=False, showinfo_extra="",
                    silent=False, concat=True) :
    command = (oiio_app("maketx") 
               + " " + oiio_relpath(infile,tmpdir) 
               + " " + extraargs
               + " -o " + oiio_relpath(outfile,tmpdir) )
    if not silent :
        command += redirect
    if concat:
        command += " ;\n"
    if showinfo:
        command += info_command (outfile, extraargs=showinfo_extra, safematch=1)
    return command



# Construct a command that will test the basic ability to read and write
# an image, appending output to the file "out.txt".  First, iinfo the
# file, including a hash (VERY unlikely not to match if we've read
# correctly).  If testwrite is nonzero, also iconvert the file to make a
# copy (tests writing that format), and then idiff to make sure it
# matches the original.
def rw_command (dir, filename, testwrite=True, use_oiiotool=False, extraargs="",
                preargs="", idiffextraargs="", output_filename="",
                safematch=False, printinfo=True) :
    fn = oiio_relpath (dir + "/" + filename, tmpdir)
    if printinfo :
        cmd = info_command (fn, safematch=safematch)
    else :
        cmd = ""
    if output_filename == "" :
        output_filename = filename
    if testwrite :
        if use_oiiotool :
            cmd = (cmd + oiio_app("oiiotool") + preargs + " " + fn
                   + " " + extraargs + " -o " + output_filename + redirect + ";\n")
        else :
            cmd = (cmd + oiio_app("iconvert") + preargs + " " + fn
                   + " " + extraargs + " " + output_filename + redirect + ";\n")
        cmd = (cmd + oiio_app("idiff") + " -a " + fn
               + " -fail " + str(failthresh)
               + " -failpercent " + str(failpercent)
               + " -hardfail " + str(hardfail)
               + " -warn " + str(2*failthresh)
               + " " + idiffextraargs + " " + output_filename + redirect + ";\n")
    return cmd


# Construct a command that will testtex
def testtex_command (file, extraargs="", silent=False, concat=True) :
    cmd = oiio_app("testtex") + " " + file + " " + extraargs + " "
    if not silent :
        cmd += redirect
    if concat:
        cmd += " ;\n"
    return cmd


# Construct a command that will run oiiotool and append its output to out.txt
def oiiotool (args, silent=False, concat=True) :
    cmd = (oiio_app("oiiotool") + " "
           + "-colorconfig " + colorconfig_file + " "
           + args)
    if not silent :
        cmd += redirect
    if concat:
        cmd += " ;\n"
    return cmd



# Check one output file against reference images in a list of reference
# directories. For each directory, it will first check for a match under
# the identical name, and if that fails, it will look for alternatives of
# the form "basename-*.ext" (or ANY match in the ref directory, if anymatch
# is True).
def checkref (name, refdirlist) :
    # Break the output into prefix+extension
    (prefix, extension) = os.path.splitext(name)
    ok = 0
    for ref in refdirlist :
        # We will first compare name to ref/name, and if that fails, we will
        # compare it to everything else that matches ref/prefix-*.extension.
        # That allows us to have multiple matching variants for different
        # platforms, etc.
        defaulttest = os.path.join(ref,name)
        if anymatch :
            pattern = "*.*"
        else :
            pattern = prefix+"-*"+extension+"*"
        for testfile in ([defaulttest] + glob.glob (os.path.join (ref, pattern))) :
            if not os.path.exists(testfile) :
                continue
            # print ("comparing " + name + " to " + testfile)
            if extension in image_extensions :
                # images -- use idiff
                cmpcommand = diff_command (name, testfile, concat=False, silent=True)
                cmpresult = os.system (cmpcommand)
            elif extension == ".txt" :
                cmpresult = text_diff (name, testfile, name + ".diff")
            else :
                # anything else
                cmpresult = 0
                if os.path.exists(testfile) and filecmp.cmp (name, testfile) :
                    cmpresult = 0
                else :
                    cmpresult = 1
            if cmpresult == 0 :
                return (True, testfile)   # we're done
    return (False, defaulttest)



# Run 'command'.  For each file in 'outputs', compare it to the copy
# in 'ref/'.  If all outputs match their reference copies, return 0
# to pass.  If any outputs do not match their references return 1 to
# fail.
def runtest (command, outputs, failureok=0) :
    err = 0
#    print ("working dir = " + tmpdir)
    os.chdir (srcdir)
    open ("out.txt", "w").close()    # truncate out.txt
    open ("out.err.txt", "w").close()    # truncate out.txt
    if os.path.isfile("debug.log") :
        os.remove ("debug.log")

    if options.path != "" :
        sys.path = [options.path] + sys.path
    print ("command = " + command)

    test_environ = None
    if (platform.system () == 'Windows') and (options.solution_path != "") and \
       (os.path.isdir (options.solution_path)):
        test_environ = os.environ
        libOIIO_args = [options.solution_path, "libOpenImageIO"]
        if options.devenv_config != "":
            libOIIO_args.append (options.devenv_config)
        libOIIO_path = os.path.normpath (os.path.join (*libOIIO_args))
        test_environ["PATH"] = libOIIO_path + ';' + test_environ["PATH"]

    for sub_command in [c.strip() for c in command.split(';') if c.strip()]:
        cmdret = subprocess.call (sub_command, shell=True, env=test_environ)
        if cmdret != 0 and failureok == 0 :
            print ("#### Error: this command failed: ", sub_command)
            print ("FAIL")
            err = 1

    for out in outputs :
        (prefix, extension) = os.path.splitext(out)
        # On Windows, change line endings of text files to unix style before
        # comparison to reference output.
        if (platform.system() == 'Windows' and os.path.exists(out)
                and extension == '.txt') :
            os.rename (out, "crlf.txt")
            os.system ("tr -d '\\r' < crlf.txt > " + out)
            if os.path.exists('crlf.txt') :
                os.remove('crlf.txt')

        (ok, testfile) = checkref (out, refdirlist)

        if ok :
            if extension in image_extensions :
                # If we got a match for an image, save the idiff results
                os.system (diff_command (out, testfile, silent=False, concat=False))
            print ("PASS: " + out + " matches " + testfile)
        else :
            err = 1
            print ("NO MATCH for " + out)
            print ("FAIL " + out)
            if extension == ".txt" :
                # If we failed to get a match for a text file, print the
                # file and the diff, for easy debugging.
                print ("-----" + out + "----->")
                print (open(out,'r').read() + "<----------")
                print ("-----" + testfile + "----->")
                print (open(testfile,'r').read() + "<----------")
                os.system ("ls -al " +out+" "+testfile)
                print ("Diff was:\n-------")
                print (open (out+".diff", 'r').read())
            if extension in image_extensions :
                # If we failed to get a match for an image, send the idiff
                # results to the console
                os.system (diff_command (out, testfile, silent=False, concat=False))
            if os.path.isfile("debug.log") and os.path.getsize("debug.log") :
                print ("---   DEBUG LOG   ---\n")
                #flog = open("debug.log", "r")
                # print (flog.read())
                with open("debug.log", "r") as flog :
                    print (flog.read())
                print ("--- END DEBUG LOG ---\n")
    return (err)


##########################################################################



#
# Read the individual run.py file for this test, which will define 
# command and outputs.
#
with open(os.path.join(test_source_dir,"run.py")) as f:
    code = compile(f.read(), "run.py", 'exec')
    exec (code)

# Allow a little more slop for slight pixel differences when in DEBUG
# mode or when running on remote CI machines.
if (os.getenv('CI') or os.getenv('DEBUG')) :
    failthresh *= 2.0
    hardfail *= 2.0
    failpercent *= 2.0


# Run the test and check the outputs
ret = runtest (command, outputs, failureok=failureok)

if ret == 0 and cleanup_on_success :
    for ext in image_extensions + [ ".txt", ".diff" ] :
        for f in glob.iglob (srcdir + '/*' + ext) :
            os.remove(f)
            #print('REMOVED ', f)

sys.exit (ret)



#!/usr/bin/env python

# Regression test for stride bugs for tiled images where resolution isn't
# a whole number of tiles.  This particular resolution mimics a particular
# failure case known to cause problems that I debugged.

# Create a file
command += (oiio_app("oiiotool") 
            + " --pattern checker 2220x1172 3 --tile 128 128 -d half -o bcheck.exr >> out.txt ;\n")


# Copy the file -- this conversion crashed when the bug was present
command += (oiio_app("iconvert") + " bcheck.exr -d float b2.exr ;\n")

# Make sure they match
command += diff_command ("bcheck.exr", "b2.exr")

#print "Running this command:\n" + command + "\n"




#!/usr/bin/env python

# Make two images that differ by a particular known pixel value
command += oiiotool("-pattern fill:color=0.1,0.1,0.1 10x10 3 -d float -o img1.exr")
command += oiiotool("-pattern fill:color=0.1,0.1,0.1 10x10 3 -d float -box:color=0.1,0.6,0.1 5,7,5,7 -o img2.exr")

# Now make sure idiff and oiiotool --diff print the right info
failureok = True
command += oiio_app("idiff") + " img1.exr img2.exr >> out.txt ;\n"
command += oiio_app("oiiotool") + " -diff img1.exr img2.exr >> out.txt ;\n"


# Outputs to check against references
outputs = [ "out.txt" ]



#!/usr/bin/env python

# This helper script takes a major.minor.patch semantic version string
# ("2.1.1") and reformats it into the dot-less zero-padded version like
# "20101".  This is necessary to turn external release designations into
# integer SpComp2 version numbers.

from __future__ import print_function
from __future__ import absolute_import
import sys

if len(sys.argv) != 2 :
    print('Need 1 argument: version number with dots')
    exit(1)

vers = sys.argv[1]
parts = vers.split('.')
print ('{:d}{:02d}{:02d}'.format(int(parts[0]), int(parts[1]), int(parts[2])))



#!/usr/bin/env python

imagedir = "ref/"
command += oiiotool ("-pattern fill:topleft=0.1:topright=0.5:bottomleft=1.0:bottomright=0.3 64x64 1 -chnames Z -d float -o out.zfile")
command += info_command ("out.zfile", extraargs="-stats")
outputs += [ "out.zfile" ]



#!/usr/bin/env python

# Test reading and writing of files with per-channel data formats.


# Few image formats support per-channel formats, but OpenEXR is one
# of them, and the OpenEXR test images contains one such image:
image = OIIO_TESTSUITE_IMAGEDIR + "/ScanLines/Blobbies.exr"

# iconvert reads and writes native format, test that.
command += (oiio_app("iconvert") + image + " blob1.exr ;\n")
command += diff_command (image, "blob1.exr")

# oiiotool uses a different code path involving ImageCache and ImageBuf,
# and will convert to float along the way.
command += (oiio_app("oiiotool") + image + " -o blob2.exr ;\n")
command += diff_command (image, "blob2.exr")


# Now we do a similar test for a tiled OpenEXR file with per-channel formats
image = OIIO_TESTSUITE_IMAGEDIR + "/Tiles/Spirals.exr"

# iconvert reads and writes native format, test that.
command += (oiio_app("iconvert") + image + " spiral1.exr ;\n")
command += diff_command (image, "spiral1.exr")

# oiiotool uses a different code path involving ImageCache and ImageBuf,
# and will convert to float along the way.
command += (oiio_app("oiiotool") + image + " -o spiral2.exr ;\n")
command += diff_command (image, "spiral2.exr")


#print "Running this command:\n" + command + "\n"




#!/usr/bin/env python 

# Slightly bump allowable failures, for slightly shifting font rendering
# with changed freetype versions.
failpercent *= 2.0

# test subimages
command += oiiotool ("--pattern constant:color=0.5,0.0,0.0 64x64 3 " +
                     "--pattern constant:color=0.0,0.5,0.0 64x64 3 " +
                     "--siappend -d half -o subimages-2.exr")
command += oiiotool ("--pattern constant:color=0.5,0.0,0.0 64x64 3 --text A -attrib oiio:subimagename layerA " +
                     "--pattern constant:color=0.0,0.5,0.0 64x64 3 --text B -attrib oiio:subimagename layerB " +
                     "--pattern constant:color=0.0,0.0,0.5 64x64 3 --text C -attrib oiio:subimagename layerC " +
                     "--pattern constant:color=0.5,0.5,0.0 64x64 3 --text D -attrib oiio:subimagename layerD " +
                     "--siappendall -d half -o subimages-4.exr")
command += oiiotool ("subimages-4.exr --subimage 3 -o subimageD3.exr")
command += oiiotool ("subimages-4.exr --subimage layerB -o subimageB1.exr")
command += oiiotool ("subimages-2.exr --sisplit -o:all=1 subimage%d.exr")


# Outputs to check against references
outputs = [ 
            "subimages-2.exr", "subimages-4.exr",
            "subimage1.exr", "subimage2.exr",
            "subimageD3.exr", "subimageB1.exr"
          ]

#print "Running this command:\n" + command + "\n"



#!/usr/bin/env python

failthresh = 0.008
anymatch = True
imagedir = "src/"
outputs = []
files = [
          "pattern2-8-rgb.psd", "pattern2-16-rgb.psd",
          #"pattern2-32-rgb.psd",
          "pattern2-8-cmyk.psd", "pattern2-16-cmyk.psd",
          "pattern2-8-multichannel.psd", "pattern2-16-multichannel.psd",
          "pattern2-8-grayscale.psd", "pattern2-16-grayscale.psd",
          #"pattern2-32-grayscale.psd",
          "pattern2-8-indexed.psd",
        ]
for f in files:
    outfile = f+".tif"
    command += rw_command (imagedir, f, testwrite=True,
                           printinfo=False, output_filename=outfile)
    outputs += [ outfile ]

outputs += [ "out.txt" ]



#!/usr/bin/env python

from __future__ import print_function
from __future__ import absolute_import
import OpenImageIO as oiio




######################################################################
# main test starts here

try:
    r = oiio.ROI()
    print ("ROI() =", r)
    print ("r.defined =", r.defined)
    r = oiio.ROI (0, 640, 100, 200)
    print ("ROI(0, 640, 100, 200) =", r)
    r = oiio.ROI (0, 640, 0, 480, 0, 1, 0, 4)
    print ("ROI(0, 640, 100, 480, 0, 1, 0, 4) =", r)
    print ("r.xbegin =", r.xbegin)
    print ("r.xend =", r.xend)
    print ("r.ybegin =", r.ybegin)
    print ("r.yend =", r.yend)
    print ("r.zbegin =", r.zbegin)
    print ("r.zend =", r.zend)
    print ("r.chbegin =", r.chbegin)
    print ("r.chend =", r.chend)
    print ("r.defined = ", r.defined)
    print ("r.width = ", r.width)
    print ("r.height = ", r.height)
    print ("r.depth = ", r.depth)
    print ("r.nchannels = ", r.nchannels)
    print ("r.npixels = ", r.npixels)
    print ("")
    print ("ROI.All =", oiio.ROI.All)
    print ("")

    r2 = oiio.ROI(r)
    r3 = oiio.ROI(r)
    r3.xend = 320
    print ("r == r2 (expect yes): ", (r == r2))
    print ("r != r2 (expect no): ", (r != r2))
    print ("r == r3 (expect no): ", (r == r3))
    print ("r != r3 (expect yes): ", (r != r3))
    print ("")

    print ("r contains (10,10) (expect yes): ", r.contains(10,10))
    print ("r contains (1000,10) (expect no): ", r.contains(1000,10))
    print ("r contains roi(10,20,10,20,0,1,0,1) (expect yes): ", r.contains(oiio.ROI(10,20,10,20,0,1,0,1)))
    print ("r contains roi(1010,1020,10,20,0,1,0,1) (expect no): ", r.contains(oiio.ROI(1010,1020,10,20,0,1,0,1)))

    A = oiio.ROI (0, 10, 0, 8, 0, 1, 0, 4)
    B = oiio.ROI (5, 15, -1, 10, 0, 1, 0, 4)
    print ("A =", A)
    print ("B =", B)
    print ("ROI.union(A,B) =", oiio.union(A,B))
    print ("ROI.intersection(A,B) =", oiio.intersection(A,B))
    print ("")

    spec = oiio.ImageSpec(640, 480, 3, oiio.UINT8)
    print ("Spec's roi is", oiio.get_roi(spec))
    oiio.set_roi (spec, oiio.ROI(3, 5, 7, 9))
    oiio.set_roi_full (spec, oiio.ROI(13, 15, 17, 19))
    print ("After set, roi is", oiio.get_roi(spec))
    print ("After set, roi_full is", oiio.get_roi_full(spec))

    print ("")

    print ("Done.")
except Exception as detail:
    print ("Unknown exception:", detail)




#!/usr/bin/env python

from __future__ import print_function
from __future__ import division
from __future__ import absolute_import
import OpenImageIO as oiio

test_xres = 3
test_yres = 3
test_nchannels = 6
test_chantypes = (oiio.TypeDesc.TypeHalf, oiio.TypeDesc.TypeHalf,
                  oiio.TypeDesc.TypeHalf, oiio.TypeDesc.TypeHalf,
                  oiio.TypeDesc.TypeFloat, oiio.TypeDesc.TypeFloat)
test_channames = ("R", "G", "B", "A", "Z", "Zback")
print ("test_chantypes ", str(test_chantypes[0]), str(test_chantypes[1]), str(test_chantypes[2]), str(test_chantypes[3]), str(test_chantypes[4]), str(test_chantypes[5]))

def set_dd_sample (dd, pixel, sample, vals) :
    if dd.samples(pixel) <= sample :
        dd.set_samples(pixel, sample+1)
    for c in range(ib.nchannels) :
        dd.set_value (pixel, c, sample, vals[c])

def add_dd_sample (dd, pixel, sample, vals) :
    set_dd_sample (dd, pixel, dd.samples(pixel), vale)


# Make a simple deep image
# Only odd pixel indes have samples, and they have #samples = pixel index.
def make_test_deep_image () :
    dd = oiio.DeepData()
    dd.init (test_xres*test_yres, test_nchannels, test_chantypes, test_channames)
    for p in range(dd.pixels) :
        if p&1 :
            dd.set_samples (p, p)
    for p in range(dd.pixels) :
        ns = dd.samples(p)
        for s in range(ns) :
            # pixels alternate R, G, B. Increasing alpha with each sample
            # in the pixel, with the last being opaque. Z increases with
            # each sample (staring at 10.0, + 1.0 for each sample), Zback
            # is 0.5 past Z.
            alpha = float(s+1)/ns
            r = 1.0 if (p % 3) == 0 else 0.0
            g = 1.0 if (p % 3) == 1 else 0.0
            b = 1.0 if (p % 3) == 2 else 0.0
            dd.set_deep_value (p, 0, s, alpha * r)   # R
            dd.set_deep_value (p, 1, s, alpha * g)   # G
            dd.set_deep_value (p, 2, s, alpha * b)   # B
            dd.set_deep_value (p, 3, s, alpha)       # A
            dd.set_deep_value (p, 4, s, 10.0+s)      # Z
            dd.set_deep_value (p, 5, s, 10.0+s+0.5)  # Zback
    return dd



def print_deep_image (dd, prefix="After init,") :
    print (prefix, "dd has", dd.pixels, "pixels,", dd.channels, "channels.")
    print ("  Channel indices: Z=", dd.Z_channel, "Zback=", dd.Zback_channel, "A=", dd.A_channel, "AR=", dd.AR_channel, "AG=", dd.AG_channel, "AB=", dd.AB_channel)
    for p in range(dd.pixels) :
        ns = dd.samples(p)
        if ns > 0 or dd.capacity(p) > 0 :
            print ("  Nsamples[", p, "] =", ns, " (capacity=", dd.capacity(p), ")", "samples:")
            for s in range(ns) :
                print ("  sample", s, ": ", end='')
                for c in range(dd.channels) :
                    print (" [%d %s] %.2f / " % (c, dd.channelname(c), dd.deep_value (p, c, s)), end='')
                print ()


def print_deep_imagebuf (buf, prefix) :
    print_deep_image (buf.deepdata(), prefix)


def test_insert_erase () :
    print ("\nTesting insert and erase...")
    dd = oiio.DeepData ()
    dd.init (3, test_nchannels, test_chantypes, test_channames)
    dd.set_samples (1, 1)
    dd.set_deep_value (1, 4, 0, 10.0)
    print_deep_image (dd, "After setting one sample:")
    dd.insert_samples (1, 0, 1)
    dd.set_deep_value (1, 4, 0, 9.0)
    dd.insert_samples (1, 2, 1)
    dd.set_deep_value (1, 4, 2, 11.0)
    print_deep_image (dd, "After inserting before and after:")
    dd.erase_samples (1, 1, 1)
    print_deep_image (dd, "After deleting the middle:")


def test_deep_copy () :
    print ("\nTesting copy_deep_pixel...")
    # Set up an image
    src = make_test_deep_image ()
    dst = make_test_deep_image ()
    dst.copy_deep_pixel (3, src, 5)
    dst.copy_deep_pixel (5, src, 3)
    print_deep_image (dst, "test_deep_copy: should swap pixels 3 and 5,")


def test_sample_split () :
    print ("\nTesting split...")
    # Set up a simple 3-pixel image
    dd = oiio.DeepData ()
    dd.init (2, test_nchannels, test_chantypes, test_channames)
    for p in range(dd.pixels) :
        dd.set_samples (p, 2)
        # first sample - reddish
        dd.set_deep_value (p, 0, 0, 0.5)   # R
        dd.set_deep_value (p, 1, 0, 0.1)   # G
        dd.set_deep_value (p, 2, 0, 0.1)   # B
        dd.set_deep_value (p, 3, 0, 0.5)   # A
        dd.set_deep_value (p, 4, 0, 10.0)  # Z
        dd.set_deep_value (p, 5, 0, 11.0)  # Zback
        # second sample - greenish
        dd.set_deep_value (p, 0, 1, 0.1)   # R
        dd.set_deep_value (p, 1, 1, 0.5)   # G
        dd.set_deep_value (p, 2, 1, 0.1)   # B
        dd.set_deep_value (p, 3, 1, 0.5)   # A
        dd.set_deep_value (p, 4, 1, 20.0)  # Z
        dd.set_deep_value (p, 5, 1, 21.0)  # Zback
    # Now do a few splits of the second pixel
    dd.split (1, 0.5)    # close, doesn't split - should have no effect
    dd.split (1, 100.5)  # far, doesn't split - should have no effect
    dd.split (1, 15.0)   # still doesn't split - should have no effect
    dd.split (1, 20.0)   # Right on an edge -- should have no effect
    dd.split (1, 20.5)   # THIS one should split
    print_deep_image (dd, "After split,")


def test_sample_sort () :
    print ("\nTesting sort...")
    # Set up a simple 2-pixel image with 4 samples
    dd = oiio.DeepData ()
    dd.init (2, test_nchannels, test_chantypes, test_channames)
    for p in range(dd.pixels) :
        dd.set_samples (p, 4)
        for s in range(dd.samples(p)) :
            dd.set_deep_value (p, 0, s, 0.1*s) # R
            dd.set_deep_value (p, 1, s, 0.0)   # G
            dd.set_deep_value (p, 2, s, 0.0)   # B
            dd.set_deep_value (p, 3, s, 0.5)   # A
            dd.set_deep_value (p, 4, s, 20.0 - s)  # Z: decreasing!
            dd.set_deep_value (p, 5, s, 20.0 - s + 0.5)  # Zback
    print_deep_image (dd, "Before z sort,")
    dd.sort (1)
    print_deep_image (dd, "After z sort of pixel 1,")


def test_merge_overlaps () :
    print ("\nTesting merge_overlaps...")
    # Set up a simple 2-pixel image with 4 samples
    dd = oiio.DeepData ()
    dd.init (2, test_nchannels, test_chantypes, test_channames)
    for p in range(dd.pixels) :
        dd.set_samples (p, 4)
        for s in range(dd.samples(p)) :
            dd.set_deep_value (p, 0, s, 0.1*s) # R
            dd.set_deep_value (p, 1, s, 0.0)   # G
            dd.set_deep_value (p, 2, s, 0.0)   # B
            dd.set_deep_value (p, 3, s, 0.5)   # A
            # Make adjacent pairs overlap exactly
            dd.set_deep_value (p, 4, s, 10.0 + int(s//2))  # Z
            dd.set_deep_value (p, 5, s, 10.0 + int(s//2) + 0.5)  # Zback
    print_deep_image (dd, "Before merge_overlaps,")
    dd.merge_overlaps (1)
    print_deep_image (dd, "After merge_overlaps of pixel 1,")


def test_merge_deep_pixels () :
    print ("\nTesting merge_deep_pixels...")
    # Set up two simple 1-pixel images with overlapping samples
    Add = oiio.DeepData ()
    Add.init (1, test_nchannels, test_chantypes, test_channames)
    Add.set_samples (0, 1)
    Add.set_deep_value (0, 0, 0, 0.5) # R
    Add.set_deep_value (0, 1, 0, 0.0) # G
    Add.set_deep_value (0, 2, 0, 0.0) # B
    Add.set_deep_value (0, 3, 0, 0.5) # A
    Add.set_deep_value (0, 4, 0, 10.0) # Z
    Add.set_deep_value (0, 5, 0, 12.0) # Zback
    Bdd = oiio.DeepData ()
    Bdd.init (1, test_nchannels, test_chantypes, test_channames)
    Bdd.set_samples (0, 1)
    Bdd.set_deep_value (0, 0, 0, 0.5) # R
    Bdd.set_deep_value (0, 1, 0, 0.0) # G
    Bdd.set_deep_value (0, 2, 0, 0.0) # B
    Bdd.set_deep_value (0, 3, 0, 0.5) # A
    Bdd.set_deep_value (0, 4, 0, 11.0) # Z
    Bdd.set_deep_value (0, 5, 0, 13.0) # Zback
    print_deep_image (Add, "Before merge_deep_pixels,")
    print_deep_image (Bdd, "And the other image,")
    Add.merge_deep_pixels (0, Bdd, 0)
    print_deep_image (Add, "After merge_deep_pixels,")


def test_occlusion_cull () :
    print ("\nTesting occlusion_cull...")
    dd = oiio.DeepData ()
    dd.init (1, test_nchannels, test_chantypes, test_channames)
    dd.set_samples (0, 3)
    for s in range(dd.samples(0)) :
        dd.set_deep_value (0, 0, s, 0.5) # R
        dd.set_deep_value (0, 1, s, 0.0) # G
        dd.set_deep_value (0, 2, s, 0.0) # B
        dd.set_deep_value (0, 3, s, (1.0 if s==1 else 0.5)) # A
        dd.set_deep_value (0, 4, s, 10.0+s) # Z
        dd.set_deep_value (0, 5, s, 10.5+s) # Zback
    print_deep_image (dd, "Before occlusion_cull,")
    dd.occlusion_cull (0)
    print_deep_image (dd, "After occlusion_cull,")

def test_opaque_z () :
    print ("\nTesting opaque_z...")
    dd = oiio.DeepData ()
    # 3 test pixels
    dd.init (3, test_nchannels, test_chantypes, test_channames)
    # First pixel: has 3 samples, middle one is opaque
    dd.set_samples (0, 3)
    for s in range(dd.samples(0)) :
        dd.set_deep_value (0, 0, s, 0.5) # R
        dd.set_deep_value (0, 1, s, 0.0) # G
        dd.set_deep_value (0, 2, s, 0.0) # B
        dd.set_deep_value (0, 3, s, (1.0 if s==1 else 0.5)) # A
        dd.set_deep_value (0, 4, s, 10.0+s) # Z
        dd.set_deep_value (0, 5, s, 10.5+s) # Zback
    # Second pixel: 3 samples, none are opaque
    dd.set_samples (1, 3)
    for s in range(dd.samples(0)) :
        dd.set_deep_value (1, 0, s, 0.5) # R
        dd.set_deep_value (1, 1, s, 0.0) # G
        dd.set_deep_value (1, 2, s, 0.0) # B
        dd.set_deep_value (1, 3, s, 0.5) # A
        dd.set_deep_value (1, 4, s, 10.0+s) # Z
        dd.set_deep_value (1, 5, s, 10.5+s) # Zback
    # Third pixel is empty
    print_deep_image (dd, "Values")
    print ("Opaque z: ", end='')
    for p in range(dd.pixels) :
        print (' %.6g' % dd.opaque_z(p), end='')
    print ()


def set_ib_sample (ib, x, y, sample, vals) :
    if ib.deep_samples(x, y) <= sample :
        ib.set_deep_samples (x, y, 0, sample+1)
    for c in range(ib.nchannels) :
        ib.set_deep_value (x, y, 0, c, sample, vals[c])

def add_ib_sample (ib, x, y, vals) :
    set_ib_sample (ib, x, y, ib.deep_samples(x,y), vals)


def test_iba_deep_holdout () :
    print ("\nTesting ImageBufAlgo.deep_holdout...")
    spec = oiio.ImageSpec (6, 1, 6, oiio.FLOAT)
    spec.deep = True
    spec.channelformats = (oiio.TypeDesc.TypeHalf, oiio.TypeDesc.TypeHalf,
                  oiio.TypeDesc.TypeHalf, oiio.TypeDesc.TypeHalf,
                  oiio.TypeDesc.TypeFloat, oiio.TypeDesc.TypeFloat)
    spec.channelnames = ("R", "G", "B", "A", "Z", "Zback")
    src = oiio.ImageBuf (spec)
    # Set up source image
    #   pixel 0: empty
    #   pixel 1: one sample close
    add_ib_sample (src, 1, 0, (0.5, 0.0, 0.0, 0.75, 10.0, 10.5))
    #   pixel 2: one sample far
    add_ib_sample (src, 2, 0, (0.5, 0.0, 0.0, 0.75, 20.0, 20.5))
    #   pixel 3: one sample close, one far
    add_ib_sample (src, 3, 0, (0.5, 0.0, 0.0, 0.75, 10.0, 10.5))
    add_ib_sample (src, 3, 0, (0.5, 0.0, 0.0, 0.75, 20.0, 20.5))
    #   pixel 4: three samples, one spans the threshold
    add_ib_sample (src, 4, 0, (0.5, 0.0, 0.0, 0.75, 10.0, 10.5))
    add_ib_sample (src, 4, 0, (0.5, 0.0, 0.0, 0.75, 15.0, 16.0))
    add_ib_sample (src, 4, 0, (0.5, 0.0, 0.0, 0.75, 20.0, 20.5))
    print_deep_imagebuf (src, "Input image")

    # Set up holdout image: depth increases left to right
    hold = oiio.ImageBuf (spec)
    for x in range(6) :
        add_ib_sample (hold, x, 0, (0, 0, 0, 0.5, 12.0, 12.5))
        add_ib_sample (hold, x, 0, (0, 0, 0, 1.0, 15.0+0.1*x, 15.0+0.1*x+0.1))
    print_deep_imagebuf (hold, "Holdout image")
    result = oiio.ImageBuf()
    oiio.ImageBufAlgo.deep_holdout (result, src, hold)
    print_deep_imagebuf (result, "Result after holdout")



######################################################################
# main test starts here

try:
    # Make a deep test image and print info about it (tests DeepData)
    dd = make_test_deep_image ()
    print_deep_image (dd)

    # Try to write the test image to an exr file
    print ("\nWriting image...")
    spec = oiio.ImageSpec (test_xres, test_yres, test_nchannels, oiio.TypeDesc.TypeFloat)
    spec.channelnames = test_channames
    spec.channelformats = test_chantypes
    spec.deep = True
    output = oiio.ImageOutput.create ("deeptest.exr")
    output.open ("deeptest.exr", spec, "create")
    output.write_deep_image (dd)
    output.close ()

    # read the exr file and double check it
    print ("\nReading image...")
    input = oiio.ImageInput.open ("deeptest.exr")
    ddr = input.read_native_deep_image ()
    if ddr :
        print_deep_image (ddr)

    test_insert_erase ()
    test_deep_copy ()
    test_sample_split ()
    test_sample_sort ()
    test_merge_overlaps ()
    test_merge_deep_pixels ()
    test_occlusion_cull ()
    test_opaque_z ()

    test_iba_deep_holdout ();

    print ("\nDone.")

except Exception as detail:
    print ("Unknown exception:", detail)




#!/usr/bin/env python

from __future__ import absolute_import
import os

oiiotoolsrcdir = os.path.join(OIIO_TESTSUITE_ROOT, "oiiotool", "src")

# test --text
command += oiiotool ("--create 320x240 3 "
            "--text:x=25:y=50:font=DroidSerif \"Hello, world\" "
            "--text:x=50:y=120:color=1,0,0:size=42 \"Go Big Red!\" "
            "-d uint8 -o text.tif >> out.txt")

# test alignment
command += oiiotool ("--create 320x320 3 "
            "--line 90,100,110,100 --line 100,90,100,110 "
            "--line 190,100,210,100 --line 200,90,200,110 "
            "--line 90,200,110,200 --line 100,190,100,210 "
            "--line 190,200,210,200 --line 200,190,200,210 "
            "--text:x=100:y=100:xalign=left:yalign=top:size=20 Topleft "
            "--text:x=200:y=100:xalign=center:yalign=baseline:size=20 Center "
            "--text:x=100:y=200:xalign=right:yalign=bottom:size=20 Rightbot "
            "--text:x=200:y=200:xalign=left:yalign=baseline:size=20 Default "
            "-d uint8 -o aligned.tif >> out.txt")

# test shadow
command += oiiotool (oiiotoolsrcdir + "/tahoe-tiny.tif "
            "--text:x=64:y=20:xalign=center:size=20:shadow=0 \"shadow = 0\" "
            "--text:x=64:y=40:xalign=center:size=20:shadow=1 \"shadow = 1\" "
            "--text:x=64:y=60:xalign=center:size=20:shadow=2 \"shadow = 2\" "
            "-o textshadowed.tif >> out.txt")

# test whether alpha works properly
command += oiiotool ("--pattern checker:color1=.2,0,0:color2=0,.2,0 320x240 3 "
            "--text:x=20:y=120:color=.5,.5,.5,.5:size=50 \"Hello, world\" "
            "-d uint8 -o textalpha.tif >> out.txt")


# Outputs to check against references
outputs = [ "text.tif", "aligned.tif", "textshadowed.tif", "textalpha.tif" ]

#print "Running this command:\n" + command + "\n"



#!/usr/bin/env python

from __future__ import absolute_import
import os

oiiotoolsrcdir = os.path.join(OIIO_TESTSUITE_ROOT, "oiiotool", "src")

# Make test pattern with increasing intensity left to right, decreasing
# alpha going down. Carefully done so that the first pixel is 0.0, last
# pixel is 1.0 (correcting for the half pixel offset).
command += oiiotool ("-pattern fill:topleft=0,0,0,1:topright=1,1,1,1:bottomleft=0,0,0,0:bottomright=1,1,1,0 256x256 4 "
                     + " -d uint8 -o greyalpha_linear.tif")


# test --colormap
command += oiiotool ("--autocc " + oiiotoolsrcdir+"/tahoe-tiny.tif" +
                     " --colormap inferno "
            + "-d uint8 -o colormap-inferno.tif")
command += oiiotool ("--autocc " + oiiotoolsrcdir+"/tahoe-tiny.tif" +
                     " --colormap .25,.25,.25,0,.5,0,1,0,0 "
            + "-d uint8 -o colormap-custom.tif")

# test unpremult/premult
command += oiiotool ("--pattern constant:color=.1,.1,.1,1 100x100 4 " 
            + " --fill:color=.2,.2,.2,.5 30x30+50+50 "
            + " -d half -o premulttarget.exr")
command += oiiotool ("premulttarget.exr --unpremult -o unpremult.exr")
command += oiiotool ("unpremult.exr --premult -o premult.exr")

# test --no-autopremult on a TGA file thet needs it.
command += oiiotool ("--no-autopremult src/rgba.tga --ch R,G,B -o rgbfromtga.png")

# test --contrast
command += oiiotool ("--autocc " + oiiotoolsrcdir+"/tahoe-tiny.tif" +
                     " -contrast:black=0.1:white=0.75 -d uint8 -o contrast-stretch.tif")
command += oiiotool ("--autocc " + oiiotoolsrcdir+"/tahoe-tiny.tif" +
                     " -contrast:min=0.1:max=0.75 -d uint8 -o contrast-shrink.tif")
command += oiiotool ("--autocc " + oiiotoolsrcdir+"/tahoe-tiny.tif" +
                     " -contrast:black=1:white=0 -d uint8 -o contrast-inverse.tif")
command += oiiotool ("--autocc " + oiiotoolsrcdir+"/tahoe-tiny.tif" +
                     " -contrast:black=1,1,.25:white=1,1,0.25 -d uint8 -o contrast-threshold.tif")
command += oiiotool ("--autocc " + oiiotoolsrcdir+"/tahoe-tiny.tif" +
                     " -contrast:scontrast=5 -d uint8 -o contrast-sigmoid5.tif")



#
# Test basic color transformation / OCIO functionality
#

# colorconvert without unpremult
command += oiiotool ("greyalpha_linear.tif --colorconvert:unpremult=0 linear sRGB -o greyalpha_sRGB.tif")
command += oiiotool ("greyalpha_linear.tif --colorconvert:unpremult=0 linear Cineon -o greyalpha_Cineon.tif")

# colorconvert with unpremult
command += oiiotool ("greyalpha_linear.tif --colorconvert:unpremult=1 linear sRGB -o greyalpha_sRGB_un.tif")
command += oiiotool ("greyalpha_linear.tif --colorconvert:unpremult=1 linear Cineon -o greyalpha_Cineon_un.tif")

# test color convert by matrix
command += oiiotool ("--autocc " + oiiotoolsrcdir+"/tahoe-tiny.tif"+
                     " "
                     + "--ccmatrix 0.805,0.506,-0.311,0,-0.311,0.805,0.506,0,0.506,-0.311,0.805,0,0,0,0,1 "
                     + "-d uint8 -o tahoe-ccmatrix.tif")

# test what happens when we read an OCIOv2 config. In particular, when
# building against OCIOv1, we should at worst have an error message, not crash
# with an uncaught exception.
command += oiiotool ("--colorconfig ../common/OpenColorIO/ocio-v2_demo.ocio -echo 'OCIOv2 config Ok'")


# To add more tests, just append more lines like the above and also add
# the new 'feature.tif' (or whatever you call it) to the outputs list,
# below.


# Outputs to check against references
outputs = [
            "colormap-inferno.tif", "colormap-custom.tif",
            "unpremult.exr", "premult.exr",
            "contrast-stretch.tif",
            "contrast-shrink.tif",
            "contrast-inverse.tif",
            "contrast-threshold.tif",
            "contrast-sigmoid5.tif",
            "rgbfromtga.png",
            "greyalpha_sRGB.tif",
            "greyalpha_Cineon.tif",
            "greyalpha_sRGB_un.tif",
            "greyalpha_Cineon_un.tif",
            "tahoe-ccmatrix.tif",
            "out.txt" ]



#!/usr/bin/env python

# FIXME -- eventually, we want more (all?) of these to work

outputs = []
imagedir = OIIO_TESTSUITE_IMAGEDIR + "/depth"
files = [
    "flower-minisblack-02.tif",   #  73x43 2-bit minisblack gray image
    "flower-minisblack-04.tif",   #  73x43 4-bit minisblack gray image
    "flower-minisblack-06.tif",   #  73x43 6-bit minisblack gray image
    "flower-minisblack-08.tif",   #  73x43 8-bit minisblack gray image
    "flower-minisblack-10.tif",   #  73x43 10-bit minisblack gray image
    "flower-minisblack-12.tif",   #  73x43 12-bit minisblack gray image
    "flower-minisblack-14.tif",   #  73x43 14-bit minisblack gray image
    "flower-minisblack-16.tif",   # 73x43 16-bit minisblack gray image
    "flower-minisblack-24.tif",   #  73x43 24-bit minisblack gray image
    "flower-minisblack-32.tif",   #  73x43 32-bit minisblack gray image
    "flower-palette-02.tif",   #73x43 4-entry colormapped image
    "flower-palette-04.tif",   #73x43 16-entry colormapped image
    "flower-palette-08.tif",   #73x43 256-entry colormapped image
    #FIXME "flower-palette-16.tif",   # 73x43 65536-entry colormapped image
    "flower-rgb-contig-02.tif",   #  73x43 2-bit contiguous RGB image
    "flower-rgb-contig-04.tif",   #  73x43 4-bit contiguous RGB image
    "flower-rgb-contig-08.tif",   #  73x43 8-bit contiguous RGB image
    "flower-rgb-contig-10.tif",   #  73x43 10-bit contiguous RGB image
    "flower-rgb-contig-12.tif",   #  73x43 12-bit contiguous RGB image
    "flower-rgb-contig-14.tif",   #  73x43 14-bit contiguous RGB image
    "flower-rgb-contig-16.tif",   #  73x43 16-bit contiguous RGB image
    "flower-rgb-contig-24.tif",   #  73x43 24-bit contiguous RGB image
    "flower-rgb-contig-32.tif",   #  73x43 32-bit contiguous RGB image
    "flower-rgb-planar-02.tif",   #  73x43 2-bit seperated RGB image
    "flower-rgb-planar-04.tif",   #  73x43 4-bit seperated RGB image
    "flower-rgb-planar-08.tif",   #  73x43 8-bit seperated RGB image
    "flower-rgb-planar-10.tif",   #  73x43 10-bit seperated RGB image
    "flower-rgb-planar-12.tif",   #  73x43 12-bit seperated RGB image
    "flower-rgb-planar-14.tif",   #  73x43 14-bit seperated RGB image
    "flower-rgb-planar-16.tif",   #  73x43 16-bit seperated RGB image
    "flower-rgb-planar-24.tif",   #  73x43 24-bit seperated RGB image
    "flower-rgb-planar-32.tif",   #  73x43 32-bit seperated RGB image
    "flower-separated-contig-08.tif",  # 73x43 8-bit contiguous CMYK image
    "flower-separated-contig-16.tif",  # 73x43 16-bit contiguous CMYK image
    "flower-separated-planar-08.tif",  # 73x43 8-bit separated CMYK image
    "flower-separated-planar-16.tif",  # 73x43 16-bit separated CMYK image
    ]

for f in files:
    command += rw_command (imagedir, f, use_oiiotool=True, preargs="-native")
    command += info_command (imagedir+'/'+f, f, verbose=False)

# Test CMYK without conversion to RGB
command += oiiotool ("-iconfig oiio:RawColor 1 " +
                     imagedir+"/flower-separated-contig-08.tif " +
                     "-attrib oiio:ColorSpace linear -o cmyk_as_cmyk.tif")
outputs += [ "cmyk_as_cmyk.tif", "out.txt" ]

print ("COMMAND= " + command)



#!/usr/bin/env python 

# Tests input image which is partial crop, partial overscan!

command += oiiotool(OIIO_TESTSUITE_IMAGEDIR + "/grid.tif " +
                    "--crop 500x1000+250+0 --fullsize 1000x800+0+100 -o grid-cropover.exr")
command += maketx_command ("grid-cropover.exr",
                           "grid-cropover.tx.exr")
command += testtex_command ("grid-cropover.tx.exr", "--wrap black")

outputs = [ "out.exr" ]



#!/usr/bin/env python

# ../openexr-images/Chromaticities:
# README         Rec709.exr     Rec709_YC.exr  XYZ.exr        XYZ_YC.exr
imagedir = OIIO_TESTSUITE_IMAGEDIR + "/Chromaticities"
files = [
    "Rec709.exr", "XYZ.exr"
]
for f in files:
    command += rw_command (imagedir, f)
# FIXME - we don't currently subsampled images (Rec709_YC.exr and XYZ_YC.exr)

# ../openexr-images/LuminanceChroma:
# CrissyField.exr  Garden.exr       StarField.exr
# Flowers.exr      MtTamNorth.exr
imagedir = OIIO_TESTSUITE_IMAGEDIR + "/LuminanceChroma"
#command += rw_command (imagedir, "CrissyField.exr", extraargs="--compression zip")
#command += rw_command (imagedir, "Flowers.exr", extraargs="--compression zip")
command += rw_command (imagedir, "Garden.exr")
#command += rw_command (imagedir, "MtTamNorth.exr")
#command += rw_command (imagedir, "StarField.exr")
# FIXME -- most of these are broken, we don't read LuminanceChroma images,
#     nor do we currently support subsampled channels



#!/usr/bin/env python

# change redirection to send stderr to a separate file
redirect = " >> out.txt 2> out.err.txt "

command += oiiotool ("src/incomplete.exr -o out.exr")
failureok = 1

outputs = [ "out.txt", "out.err.txt" ]



#!/usr/bin/env python 

command += oiiotool(OIIO_TESTSUITE_IMAGEDIR + "/grid.tif " +
                    "--crop 512x512+200+100 -o grid-crop.tif")
command += maketx_command ("grid-crop.tif",
                           "grid-crop.tx")
command += testtex_command ("grid-crop.tx", "--wrap black")

outputs = [ "out.exr" ]
